<?php
/**
 * Controller is the customized base controller class.
 * All controller classes for this application should extend from this base class.
 */
class Controller extends CController
{
	/**
	 * @var string the default layout for the controller view. Defaults to '//layouts/column1',
	 * meaning using a single column layout. See 'protected/views/layouts/column1.php'.
	 */
	public $layout='//layouts/column1';
	/**
	 * @var array context menu items. This property will be assigned to {@link CMenu::items}.
	 */
	public $menu=array();
	/**
	 * @var array the breadcrumbs of the current page. The value of this property will
	 * be assigned to {@link CBreadcrumbs::links}. Please refer to {@link CBreadcrumbs::links}
	 * for more details on how to specify this property.
	 */
	public $breadcrumbs=array();

	public $title=null;

	public $titleAction=null;

	private $urlReferrer=null;

	public function __construct($id)
	{
		$this->setServerReferer(Yii::app()->getRequest()->getUrlReferrer());
		parent::__construct($id);
	}

	public function getAccessRules($controller)
	{
		if ( !Yii::app()->user->isGuest && isset(Yii::app()->user->accessRules[$controller])){
			return array('actions'=> $this->isAllAccess(Yii::app()->user->accessRules[$controller]),
						 'users'=> array(Yii::app()->user->name));
		}

		return array('actions'=> array('_'),
					 'users'=> array('*'));
	}

	protected function isAllAccess($rules)
	{
		foreach ($rules as $key => $value) {
			if ($value == '*'){
				return array();
			}
		}

		return $rules;
	}

	/*
	 *
	 * Specifies the access control rules.
	 * Access Control List ou Lista de controle de acesso (também conhecida pelo acrônimo ACL)
	 * é definida pela área de ciência da computação como uma lista que define quem tem permissão
	 * de acesso a certos serviços. Isso é, para quem um servidor deve permitir ou negar
	 * determinada tarefa. É normalmente uma lista de princípios com os tipos de acesso
	 * definido para cada usuário ou grupo.
	 *
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 *
	 */
	public function accessRules()
	{
		$accessRules = $this->getAccessRules(Yii::app()->getController()->getId());
		return array(
				array('allow',
						'actions'=>$accessRules['actions'],
						'users'=>$accessRules['users'],
				),
				array('deny',  // deny all users
						'users'=>array('*'),
				)
		);
	}

	protected function isAllAccessAction($rules, $action)
	{
		foreach ($rules as $key => $value) {
			if ($value == $action){
				return true;
			}
		}

		return false;
	}

	public function isAccessBotton($controller, $action)
	{
		if ( !Yii::app()->user->isGuest ){
			return $this->isAllAccessAction(Yii::app()->user->accessRules[$controller], $action);
		}

		return false;
	}

	private function setServerReferer($url)
	{
		$this->urlReferrer = $url;
	}

	public function getServerReferer()
	{
		$isRepeat = strpos($this->urlReferrer, Yii::app()->request->url);
		$this->urlReferrer = empty($isRepeat)?$this->urlReferrer:array('site/index');

		return $this->urlReferrer;
	}

	static public function getSituacao($id = null)
	{
		$situacao = array(
				'0'=>'<span class="label label-important">'.Yii::t('app', 'generic.sitinativo').'</span>',
				'1'=>'<span class="label label-success">'.Yii::t('app', 'generic.sitativo').'</span>'
		);
		return isset($situacao[$id])?$situacao[$id]:$situacao;
	}
}
