<?php

/**
 * UserIdentity represents the data needed to identity a user.
 * It contains the authentication method that checks if the provided
 * data can identity the user.
 */
class UserIdentity extends CUserIdentity
{
	/**
	 * Authenticates a user.
	 * The example implementation makes sure if the username and password
	 * are both 'demo'.
	 * In practical applications, this should be changed to authenticate
	 * against some persistent user identity storage (e.g. database).
	 * @return boolean whether authentication succeeds.
	 */
	private $_id;

	public function authenticate()
	{
		$user = Usuario::getUsuarioAutenticado($this->username);
// 		XDebug::xd($user);
		if(empty($user)){
			$this->errorCode=self::ERROR_UNKNOWN_IDENTITY;

			$user = Usuario::getUsuario($this->username);
			if ($user['idusuariostatus'] == 2){ // User lock!
				Yii::app()->user->setFlash('erro', yii::t('app', 'erro.loginAguardandoLiberacao'));
			}elseif ($user['idusuariostatus'] == 4){ // User lock!
				Yii::app()->user->setFlash('erro', yii::t('app', 'erro.loginBloqueado'));
			}else{
				Yii::app()->user->setFlash('erro', yii::t('app', 'erro.loginErro'));
				$this->errorCode=self::ERROR_USERNAME_INVALID;
			}
		}else if ($user[0]['dcsenha'] !== md5($this->password)){ // Invalid password!
			Yii::app()->user->setFlash('erro', yii::t('app', 'erro.loginErro'));
			$this->errorCode=self::ERROR_PASSWORD_INVALID;
		}else{
			$this->_id = $user[0]['idusuario'];
			$MenuSistema = new MenuSistema();
			$menuUser = $MenuSistema->getMenuUsuarioSistema($this->_id, $user[0]['coperfilacesso']);

			$this->setState('profileUser' , $user[0]);
			$this->setState('profilesUser', $user);
			$this->setState('menuUser', $menuUser);
			$this->setState('idMoodle', is_null($user[0]['idmoodle'])?0:$user[0]['idmoodle']);

			$this->errorCode=self::ERROR_NONE;
			$this->username = $user[0]['coperfilacesso'];

			$UsuarioPerfilAcesso = new UsuarioPerfilAcesso();
			$UsuarioPerfilAcesso->atualizaAcesso($this->_id, $this->username);

			$this->setState('accessRules', $UsuarioPerfilAcesso->getMyAccessRules($this->_id, $user[0]['coperfilacesso']));

		}

		return !$this->errorCode;
	}

	public function getId()
	{
		return $this->_id;
	}
}