<?php

class TutorController extends Controller
{
	public $layout='//layouts/column2';
	public $title=null;
	public $shortname;

	public function init()
	{
		$this->title = Yii::t('app', 'title.tutor');
	}

	public function filters()
	{
		return array(
				'accessControl', // perform access control for CRUD operations
		);
	}
	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
				array('allow', // allow admin user to perform 'admin' and 'delete' actions
						'actions'=>array('main','delete','index','view','create','update','listaTurma',
								'listaTurmaNota','listaNotaAlunos','enviarMensagem','enviaEmailAluno',
								'notasAluno','listaCursosAlunosAprovar','listaAlunosAprovar','aprovarAluno',
								'desaprovarAluno','listaAlunosTurma','statusAluno','listaCursosLiberarCertificados',
								'listaAlunosCertificar','dashboardTutorSupervisor', 'naoAcessaPortal','questionariosAtrasados',
                                'atividadesAtrasadas', 'forumAtrasado', 'notasAlunoCurso', 'listaNotasTurmaForum',
                                'listaNotasTurmaQuestionario'),
						'users'=>array('admin','tutor','supervisor'),
				),
				array('deny',  // deny all users
						'users'=>array('*'),
				),
		);
	}

	public function actionIndex()
	{
		$this->render('index');
	}

	public function actionListaTurma($nota = NULL, $breadcrumb = 'title.acompanharFrequencia')
	{
		$curso = NULL;
		$turma = NULL;

		$cursoObj = new Curso();
		$turmaObj = new CursoTurma();

		if (isset($_POST['Curso'])) {
			$cursoObj->setAttributes($_POST['Curso']);
		}

		if (isset($_POST['CursoTurma'])) {
			$turmaObj->setAttributes($_POST['CursoTurma']);
		}

		$status  = (isset($_POST['Curso']['situacao']))?$_POST['Curso']['situacao']:NULL;

		$data['userid'] = Yii::app()->user->profileUser['idmoodle'];

		$data['roleid'] = Yii::app()->user->profileUser['idpapel'];

		$this->render('listaTurma',
				array(
						'model'   => $cursoObj,
						'turma'   => $turmaObj,
						'criteria'=> $turmaObj->gridListaTurma($data, $status, $cursoObj),
						'nota'    => $nota,
						'situacao'=> $status,
						'migalha' => $breadcrumb
				)
		);
	}

	public function actionListaTurmaNota()
	{
		self::actionListaTurma(TRUE, 'breadcrumbs.acompanharNotaAluno');
	}

	public function actionListaAlunosTurma()
	{
		$idTurma = Yii::app()->getRequest()->getParam('id');
		$qtdDias = (Yii::app()->getRequest()->getParam('dias_sem_acesso') == NULL)
		?1
		:Yii::app()->getRequest()->getParam('dias_sem_acesso');

		$cursoTurma = new CursoTurma();

		$this->render('listaAlunosTurma',
				array(
					'criteria' => $cursoTurma->alunoTurmaDiasSemAcessar($idTurma, $qtdDias),
					'curso' => $cursoTurma->findByAttributes(array('id'=>$idTurma))
				)
		);

	}

	public function actionListaNotaAlunos()
	{
		$idTurma = Yii::app()->getRequest()->getParam('id');

		$cursoTurma = new CursoTurma();
		$this->title = Yii::t('app', 'title.listaNotaAlunosTurma');
		$this->render('listaNotaAlunos',
				array(
					'curso' => $cursoTurma->findByAttributes(array('id'=>$idTurma)),
					//'criteria' => $cursoTurma->notasAlunoTurma($idTurma),
                    'dataProvider' => $cursoTurma->notasAlunoTurmaPlanilha($idTurma),
                    'dataProviderInd' => $cursoTurma->indicadoresAlunoTurma($idTurma),
					'idTurma'  => $idTurma,
                    'migalha'  => $_REQUEST['migalha']
				)
		);


	}

	public function actionEnviarMensagem()
	{
		$idUsuarios = Yii::app()->getRequest()->getParam('userid');

		$session=new CHttpSession;
		$session->open();
		$session->remove('idUsuarios');
		$session->add('idUsuarios', $idUsuarios);

		$curso = new CursoUsuarioPapel();
		$email = new Email();
		$this->render('enviarMensagem',
				array(
						'curso' 	 => $curso,
						'email'   	 => $email,
						'idUsuarios' => $idUsuarios
				)
		);

	}

	public function actionEnviaEmailAluno()
	{
		$dadosEmail = Yii::app()->getRequest()->getParam('Email');
		$session=new CHttpSession;
		$session->open();

		$idUsuarios = $session->get('idUsuarios');

		$cursoTurma = new CursoTurma();

		$emailUsuarios = $cursoTurma->getEmailUsuarios($idUsuarios);

		$mail = Yii::app()->getComponents(false);
		$sm = Yii::app()->mail;
		$transport = $sm->smtpTransport($mail['mail']['hostName'], $mail['mail']['hostPort'])
		->setUsername($mail['mail']['user'])
		->setPassword($mail['mail']['password'])
		->setEncryption('ssl');

		$mailer = $sm->mailer($transport);

		$message = $sm->newMessage($dadosEmail['assunto'])
		->setFrom(array($mail['mail']['user']))
		->setBcc($emailUsuarios)
		->addPart($dadosEmail['dccorpoemail'], 'text/html')
		->setBody('');

		// Send mail
		$result = $mailer->send($message);

		$contInscricao = new ControleInscricao();
		$contInscricao->updateContatoEMail($idUsuarios);

		if ($result === FALSE || $result == 0) {
			// 			throw new CException(Yii::t('yii','Application base path "{path}" is not a valid directory.',
			// 				array('{path}'=>$path)));
			throw new CException('Erro no Envio de Email');
		}

		$session->remove('idUsuarios');

		$this->redirect('?r=tutor/listaTurma');

	}

	public function actionNotasAluno()
	{
		$userId 	  = Yii::app()->getRequest()->getParam('id');
		$idTurma 	  = Yii::app()->getRequest()->getParam('idTurma');

		$curso         = new Curso();
		$notaCurso     = new NotaCurso();
		$notaAtividade = new NotaAtividade();

		$cursoTurma = new CursoTurma();
		$dados = $cursoTurma->find('id = '.$idTurma);

		$notaCurso->attributes     = array('userid'=>$userId, 'courseid'=>$dados->courseid);
		$notaAtividade->attributes = array('userid'=>$userId, 'idcurso'=>$dados->courseid);

		$this->render('notasAluno',array(
				'curso'         => $curso->findByPk($dados->courseid),
				'notaCurso'     => $notaCurso->search(),
				'notaAtividade' => $notaAtividade->search(),
				'userid'        => $userId,
                'idTurma'       => $idTurma,
                'nomeUsuario'   => Usuario::getNomeUsuario($userId),
                'migalha'       => $_REQUEST['migalha']
		));
	}

	public function actionListaCursosAlunosAprovar()
	{
		$data   = NULL;
		$status = NULL;

		$model = $this->dataList($data, $status);

		$data['userid'] = Yii::app()->user->profileUser['idmoodle'];

		$data['roleid'] = Yii::app()->user->profileUser['idpapel'];


		$this->render('listaCursos',array(
				'model'			 => $model,
				'cursosAluno'    => $model->gridListaTurma($data, $status),
				'curso'			 => new Curso(),
				'migalha'		 => 'breadcrumbs.aprovarAlunos',
		));
	}

	public function actionListaCursosLiberarCertificados()
	{
		$data   = NULL;
		$status = NULL;

		$model = $this->dataList($data, $status);

		$data['userid'] = Yii::app()->user->profileUser['idmoodle'];

		$data['roleid'] = Yii::app()->user->profileUser['idpapel'];

		$this->render('listaCursosLiberarCertificados',array(
				'model'			 => $model,
				'cursosAluno'    => $model->gridListaTurma($data, $status),
				'curso'			 => new Curso()
		));
	}

	protected function dataList(&$data, &$status)
	{

		$status  = (Yii::app()->getRequest()->getParam('status')!= '')
		?Yii::app()->getRequest()->getParam('status'):NULL;

		$model   = new CursoTurma();
		$model->unsetAttributes();

		if(Yii::app()->getRequest()->getParam('CursoTurma') != '') {
			$data = Yii::app()->getRequest()->getParam('CursoTurma');
			$model->attributes = Yii::app()->getRequest()->getParam('CursoTurma');
		}

		return $model;

	}

	public function actionListaAlunosAprovar()
	{
		$this->title = Yii::t('app', 'title.listaAprovarAlunos');
		$nota = Yii::app()->getRequest()->getParam('NotaAtividade');
		if(is_array($nota)) {
			$nota = $nota['vlnota'];
		}
		$this->dataView('listaAlunosAprovar', $nota);
		Yii::app()->end();
	}

	public function actionListaAlunosCertificar()
	{
		$this->title = Yii::t('app', 'title.aprovarAlunos');
		$this->dataView('listaAlunosCertificar', NULL, 'A');
		Yii::app()->end();
	}

	protected function dataView($view, $nota = NULL, $status = NULL)
	{
		$idTurma = Yii::app()->getRequest()->getParam('id');

		$cursoTurma = new CursoTurma();

		$this->render($view,
				array(
						'criteria' 		=> $cursoTurma->alunoTurmaAprovar($idTurma, $nota, $status),
						'curso' 		=> $cursoTurma->findByAttributes(array('id'=>$idTurma)),
						'notaAtividade' => new NotaAtividade(),
						'turma' 		=> $idTurma
				)
		);
	}


	public function actionStatusAluno()
	{
		$idUsuarios = Yii::app()->getRequest()->getParam('userid');
		$idturma    = Yii::app()->getRequest()->getParam('idturma');
		$tipo       = Yii::app()->getRequest()->getParam('tipo');

		if (!is_array($idUsuarios)) {
			$idUsuarios = array($idUsuarios);
		}

		$contInscricao = new ControleInscricao();
		$arrAluno = $contInscricao->statusAluno($idUsuarios, $idturma);

		if($tipo == 'aprovar') {
			$this->statusAlunoAprovarDesaprovar($arrAluno, $idturma, $contInscricao);
		}

		$this->statusCertificarRetirar($arrAluno, $idturma, $contInscricao);

	}

	protected function statusAlunoAprovarDesaprovar($arrAluno, $idturma, $contInscricao)
	{
		foreach($arrAluno as $key => $value){
			switch($value['insituacaoalunocurso']){
				case "A" :
					$arrAluno[$key]['insituacaoalunocurso'] = "C";
					break;
				case "C" :
					$arrAluno[$key]['insituacaoalunocurso'] = "A";
					break;
			}
		}

		$contInscricao->atualizaStatusAluno($arrAluno, $idturma);

		Yii::app()->user->setFlash('success', Yii::t('app', 'success.operacaoSucesso'));

		$this->redirect(Yii::app()->createUrl('tutor/listaAlunosAprovar', array('id' => $idturma)));
		Yii::app()->end();
	}

	protected function statusCertificarRetirar($arrAluno, $idturma, $contInscricao)
	{
		foreach($arrAluno as $key => $value){
			switch($value['insituacaoalunocurso']){
				case "L" :
					$arrAluno[$key]['insituacaoalunocurso'] = "A";
					break;
				case "A" :
					$arrAluno[$key]['insituacaoalunocurso'] = "L";
					break;
			}
		}

		$contInscricao->atualizaStatusAluno($arrAluno, $idturma);

		Yii::app()->user->setFlash('success', Yii::t('app', 'success.operacaoSucesso'));

		$this->redirect(Yii::app()->createUrl('tutor/listaAlunosCertificar', array('id' => $idturma)));
		Yii::app()->end();
	}


	public function actionNaoAcessaPortal()
	{
		$this->title = Yii::t('app', 'title.dashboardTutorSupervisor');
		$turma['id'] = Yii::app()->getRequest()->getParam('idturma');

		$cursoTurma = new CursoTurma();
		$usuInscricao = new UsuarioInscricao();
		$cursoUsuarioAcesso = new CursoUsuarioAcesso();

		$cursoTurma->setAttributes($turma);

		$this->render(
				'naoAcessaPortal',
				array(
						'dadosCurso' => $cursoTurma->dadosCursoTurma($cursoTurma->id),
						'criteria'   =>	$cursoUsuarioAcesso->diasSemAcessar($cursoTurma, FALSE, FALSE),
						'turma'      => $cursoTurma->id
				)
		);

	}

	public function actionAtividadesAtrasadas()
	{
		$this->title = Yii::t('app', 'title.dashboardTutorSupervisor');
		$turma['id'] = Yii::app()->getRequest()->getParam('idturma');

		$cursoTurma = new CursoTurma();
		$usuInscricao = new UsuarioInscricao();

		$cursoTurma->setAttributes($turma);

		$this->render(
				'atividadesAtrasadas',
				array(
						'dadosCurso' => $cursoTurma->dadosCursoTurma($cursoTurma->id),
						'criteria'   => $usuInscricao->tarefasAtrasadas($cursoTurma, FALSE, FALSE),
						'turma'      => $cursoTurma->id
				)
		);

	}

	public function actionQuestionariosAtrasados()
	{
		$this->title = Yii::t('app', 'title.dashboardTutorSupervisor');
		$turma['id']   = Yii::app()->getRequest()->getParam('idturma');

		$cursoTurma = new CursoTurma();
		$usuInscricao = new UsuarioInscricao();

		$cursoTurma->setAttributes($turma);

		$this->render(
				'questionariosAtrasados',
				array(
						'dadosCurso' => $cursoTurma->dadosCursoTurma($cursoTurma->id),
						'criteria'   => $usuInscricao->questionariosAtrasados($cursoTurma, FALSE, FALSE),
						'turma'      => $cursoTurma->id
				)
		);

	}

	public function actionForumAtrasado()
	{
		$this->title = Yii::t('app', 'title.dashboardTutorSupervisor');
		$turma['id']   = Yii::app()->getRequest()->getParam('idturma');

		$cursoTurma = new CursoTurma();
		$usuInscricao = new UsuarioInscricao();

		$cursoTurma->setAttributes($turma);

		$this->render(
				'forumAtrasado',
				array(
						'dadosCurso' => $cursoTurma->dadosCursoTurma($cursoTurma->id),
						'criteria'   => $usuInscricao->forumAtrasados($cursoTurma, FALSE, FALSE),
						'turma'      => $cursoTurma->id
				)
		);

	}

	public function actionNotasAlunoCurso()
	{
		$this->title = Yii::t('app', 'title.dashboardTutorSupervisor');

		$turma['id'] = Yii::app()->getRequest()->getParam('idturma');

		$cursoTurma = new CursoTurma();
		$notaCurso  = new NotaCurso();
		$cursoTurma->setAttributes($turma);

		$dadosCursoTurma = $cursoTurma->search()->getData();

		$this->render(
				'notasAlunoCurso',
				array(
						'dadosCurso' => $cursoTurma->dadosCursoTurma($cursoTurma->id),
						'criteria'   => $notaCurso->notasAlunoCurso($dadosCursoTurma[0]->courseid),
						'turma'      => $cursoTurma->id
				)
		);
	}

    public function actionListaNotasTurmaForum(){
        self::actionListaNotasTurmaAtividade(Yii::app()->getRequest()->getParam('idTurma'),'forum',Yii::app()->getRequest()->getParam('migalha'));
    }

    public function actionListaNotasTurmaQuestionario(){
        self::actionListaNotasTurmaAtividade(Yii::app()->getRequest()->getParam('idTurma'),'quiz',Yii::app()->getRequest()->getParam('migalha'));
    }

    public function actionListaNotasTurmaAtividade($idturma,$tipo,$migalha){
		$this->title = Yii::t('app', 'title.'.($tipo=='forum'?'listaNotasTurmaForum':'listaNotasTurmaQuestionario'));

		$turma['id'] = $idturma;

		$cursoTurma = new CursoTurma();
		$cursoTurma->setAttributes($turma);

		$this->render(
				'notasTurmaAtividade',
				array(
						'dadosTurma' => $cursoTurma->alunosTurma($cursoTurma->id),
						'cursoTurma' => $cursoTurma,
                        'curso'      => $cursoTurma->findByAttributes(array('id'=>$cursoTurma->id)),
						'idTurma'    => $cursoTurma->id,
                        'tipo'       => $tipo,
                        'migalha'    => $migalha,
				)
		);
    }
}