<?php

/*
 * DateTimeI18NBehavior
 * Automatically converts date and datetime fields to I18N format
 *
 * Author: Ricardo Grana <rickgrana@yahoo.com.br>, <ricardo.grana@pmm.am.gov.br>
 * Version: 1.1
 * Requires: Yii 1.0.9 version
 */

class DateTimeI18NBehavior  extends CActiveRecordBehavior
{
	public $dateOutcomeFormat = 'd/m/Y';
	public $dateTimeOutcomeFormat = 'd/m/Y H:i:s';

	public $dateIncomeFormat = 'yyyy-MM-dd';
	public $dateTimeIncomeFormat = 'yyyy-MM-dd hh:mm:ss';

	protected $event = null;
	protected $format = null;

	public function beforeSave($event)
	{
		$this->event = $event;

		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime');

			switch ($column->dbType) {
				case 'date':
				case 'datetime':
					$this->formatInDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}

		return true;
	}


	public function afterFind($event)
	{
		$this->event = $event;

		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime');

			switch ($column->dbType) {
				case 'date':
					$this->format = $this->dateOutcomeFormat;
				case 'datetime':
					$this->format = $this->dateTimeOutcomeFormat;
					$this->formatOutDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}

		return true;
	}

	public function beforeFind($event)
	{
		$this->beforeSave($event);
	}

	private function formatInDateTime($column, $columnName)
	{
		if (!strlen($this->event->sender->$columnName)){
			$this->event->sender->$columnName = null;
			return;
		}

		$dateTime = explode(' ', $this->event->sender->$columnName);
		$this->event->sender->$columnName = date('Y-m-d',
												 CDateTimeParser::parse($dateTime[0],
																		Yii::app()->locale->dateFormat)).
											(isset($dateTime[1])?' '.$dateTime[1]:'');
	}

	private function formatOutDateTime($column, $columnName)
	{
		if (!strlen($this->event->sender->$columnName)){
			$this->event->sender->$columnName = null;
			return;
		}

		$this->event->sender->$columnName = strtotime($this->event->sender->$columnName);
		$this->event->sender->$columnName = date($this->format,
												 $this->event->sender->$columnName );
	}
}
