<?php

/*
 * DateTimeI18NBehavior
 * Automatically converts date and datetime fields to I18N format
 *
 * Author: Ricardo Grana <rickgrana@yahoo.com.br>, <ricardo.grana@pmm.am.gov.br>
 * Version: 1.1
 * Requires: Yii 1.0.9 version
 */

class DateTimeI18NBehavior  extends CActiveRecordBehavior
{
	public $dateOutcomeFormat = 'd/m/Y';
	public $dateTimeOutcomeFormat = 'd/m/Y H:i:s';

	public $dateIncomeFormat = 'yyyy-MM-dd';
	public $dateTimeIncomeFormat = 'yyyy-MM-dd hh:mm:ss';

	public $event = null;
	public $format = null;

	public function beforeSave($event)
	{
		$this->event = $event;

		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime');

			switch ($column->dbType) {
				case 'date':
					$this->format = 'Y-m-d';
				case 'datetime':
					$this->format = 'Y-m-d H:i:s';
					$this->formatInDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}
		return true;
	}

	private function formatInDateTime($column, $columnName)
	{
		$this->event->sender->$columnName = date($this->format,
				CDateTimeParser::parse($this->event->sender->$columnName,
						Yii::app()->locale->dateFormat));
	}

	private function formatOutDateTime($column, $columnName)
	{
		$this->event->sender->$columnName = strtotime($this->event->sender->$columnName);
		$this->event->sender->$columnName = date($this->format,
												 $this->event->sender->$columnName );
	}

// 	public function beforeSave($event){

// 		//search for date/datetime columns. Convert it to pure PHP date format
// 		foreach($event->sender->tableSchema->columns as $columnName => $column){

// 			$column->dbType = (strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime';

// 			if (($column->dbType != 'date') && ($column->dbType != 'datetime')) continue;

// 			if (!strlen($event->sender->$columnName)){
// 				$event->sender->$columnName = null;
// 				continue;
// 			}

// 			if (($column->dbType == 'date')) {
// 				$event->sender->$columnName = date(	$this->dateOutcomeFormat,
// 													CDateTimeParser::parse(	$event->sender->$columnName,
// 																			Yii::app()->locale->dateFormat));
// 			}else{
// 				$dateTime = explode(' ', $event->sender->$columnName);

// 				if (!isset($dateTime[1]))
// 					continue;

// 				if ( !isset($dateTime[1]) ){
// 					$dateTime[1] = Yii::app()->dateFormatter
// 											 ->formatDateTime(	CDateTimeParser::parse( $event->sender->$columnName,
// 																						$this->dateTimeIncomeFormat),
// 																null,'medium');
// 				}

// 				$event->sender->$columnName = $dateTime[0] .' '. $dateTime[1];

// 				$event->sender->$columnName = date($this->dateTimeOutcomeFormat,
// 						CDateTimeParser::parse(	$event->sender->$columnName,
// 												strtr(	Yii::app()->locale->dateTimeFormat,
// 														array(	"{0}" => Yii::app()->locale->timeFormat,
// 														  		"{1}" => Yii::app()->locale->dateFormat))));
// 			}

// 		}
// 		return true;
// 	}

	public function afterFind($event)
	{
		$this->event = $event;

		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime');

			switch ($column->dbType) {
				case 'date':
					$this->format = $this->dateOutcomeFormat;
				case 'datetime':
					$this->format = $this->dateTimeOutcomeFormat;
					$this->formatOutDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}
		return true;
	}

// 	public function afterFind($event)
// 	{
// 		$this->event = $event;

// 		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
// 			$column->dbType = (strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime';

// 			if (($column->dbType != 'date') and ($column->dbType != 'datetime')) continue;

// 			if (!strlen($this->event->sender->$columnName)){
// 				$this->event->sender->$columnName = null;
// 				continue;
// 			}

// 			$this->event->sender->$columnName = strtotime($this->event->sender->$columnName);
// 			if ($column->dbType == 'date'){
// 				$this->event->sender->$columnName = date($this->dateOutcomeFormat,
// 														 $this->event->sender->$columnName );
// 			}else{
// 				$this->event->sender->$columnName = date($this->dateTimeOutcomeFormat,
// 														 $this->event->sender->$columnName );
// 			}
// 		}
// 		return true;
// 	}

	public function beforeFind($event)
	{
		$this->beforeSave($event);
	}
}
