<?php

/*
 * DateTimeI18NBehavior
* Automatically converts date and datetime fields to I18N format
*
* Author: Ricardo Grana <rickgrana@yahoo.com.br>, <ricardo.grana@pmm.am.gov.br>
* Version: 1.1
* Requires: Yii 1.0.9 version
*/

class Format18NBehavior  extends CActiveRecordBehavior
{
	public $dateOutcomeFormat = 'd/m/Y';
	public $dateTimeOutcomeFormat = 'd/m/Y H:i:s';

	public $dateIncomeFormat = 'yyyy-MM-dd';
	public $dateTimeIncomeFormat = 'yyyy-MM-dd hh:mm:ss';

	protected $event = null;
	protected $format = null;

	public function beforeSave($event)
	{
		$this->event = $event;
		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)
					?$column->dbType
					:'datetime');

			switch ($column->dbType) {
				case 'bit':
				case 'bool':
				case 'boolean':
					$this->formatInBoolean($column, $columnName);
					break;
				case 'date':
				case 'datetime':
					$this->formatInDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}

		return true;
	}

	public function afterFind($event)
	{
		$this->event = $event;

		foreach($this->event->sender->tableSchema->columns as $columnName => $column){
			$column->dbType = strtolower((strpos($column->dbType, 'timestamp') === false)?$column->dbType:'datetime');
			switch ($column->dbType) {
				case 'bit':
				case 'bool':
				case 'boolean':
					$this->formatOutBoolean($column, $columnName);
					break;
				case 'date':
					$this->format = $this->dateOutcomeFormat;
					$this->formatOutDateTime($column, $columnName);
					break;
				case 'datetime':
					$this->format = $this->dateTimeOutcomeFormat;
					$this->formatOutDateTime($column, $columnName);
					break;
				default:
					continue;
					break;
			}
		}

		return true;
	}

	public function beforeFind($event)
	{
		$this->beforeSave($event);
	}

	private function formatInDateTime($column, $columnName)
	{
		if (!strlen($this->event->sender->$columnName)){
			$this->event->sender->$columnName = null;
			return;
		}elseif (is_object($this->event->sender->$columnName)){
			return;
		}

		// 		if ($column->name == 'dtinscricao')
		// 			XDebug::xd($this->event->sender->$columnName);

		$dateTime = explode(' ', $this->event->sender->$columnName);
		$this->event->sender->$columnName = date('Y-m-d',
				CDateTimeParser::parse($dateTime[0],
						Yii::app()->locale->dateFormat)).
						(isset($dateTime[1])?' '.$dateTime[1]:'');
	}

	private function formatOutDateTime($column, $columnName)
	{
		if (!strlen($this->event->sender->$columnName)){
			$this->event->sender->$columnName = null;
			return;
		}

		$this->event->sender->$columnName = strtotime($this->event->sender->$columnName);
		$this->event->sender->$columnName = date($this->format,
				$this->event->sender->$columnName );
	}

	private function formatInBoolean($column, $columnName)
	{
		if (!strlen($this->event->sender->$columnName)){
			$this->event->sender->$columnName = null;
			return;
		}elseif (is_object($this->event->sender->$columnName)){
			return;
		}

		$this->event->sender->$columnName = new CDbExpression("'".$this->event->sender->$columnName."'");
	}

	private function formatOutBoolean($column, $columnName)
	{
		if ($this->event->sender->$columnName === null){
			return;
		}

		switch ($this->event->sender->$columnName) {
			case false:
				$this->event->sender->$columnName= "0";
				break;
			case true:
				$this->event->sender->$columnName= "1";
				break;
			default:
				continue;
				break;
		}
	}
}
