<?php

// auto-loading fix
Yii::setPathOfAlias('Condicao', dirname(__FILE__).'/base');
Yii::import('Condicao.*');

class Condicao extends BaseCondicao
{
	public $data = null;

	// Add your model-specific methods here. This file will not be overriden by gtc except you force it.
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function init()
	{
		return parent::init();
	}

	public function __toString() {
		return (string) $this->txcondicao;
	}

	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function rules()
	{
		return array_merge(
				array(),
				parent::rules()
		);
	}

	public function preCreate($type)
	{
		if (!is_array($this->data))
			return $this->addError('erro', Yii::t('app', 'erro.informacoesInsuficiente'));

		switch ($type) {
			case 'formacaoCadastral':
				$this->cotipopesquisa = 'FCA';
				$this->validadeFormacaoCadastral();
				break;
			case 'projetoCurso':
				$this->cotipopesquisa = 'PCA';
				$this->validadeProjetoCurso();
				break;
			case 'pesquisaAvaliacao':
				$this->cotipopesquisa = 'PAA';
				$this->validadePesquisaAvaliacao();
				break;
			default:
				throw new CHttpException(404, Yii::t('app', 'erro.desconhecido'));
				break;
		}

		if (!$this->hasErrors()){
			if ($this->idcondicao){
				$Condicao = self::preFind($this->idcondicao);
				$Condicao->txcondicao = serialize($this->data);
				$Condicao->dtcriacao = new CDbExpression('NOW()');
				$Condicao->idusuariocriacao = Yii::app()->user->id;
				$Condicao->save();
			}else{
				if($this->validadeCondicao()){
					$Condicao = new Condicao();
					$Condicao->idpesquisa = $this->idpesquisa;
					$Condicao->cotipopesquisa = $this->cotipopesquisa;
					$Condicao->idusuariocriacao = Yii::app()->user->id;
					$Condicao->txcondicao = serialize($this->data);
					$Condicao->dtcriacao =  new CDbExpression('NOW()');
					$Condicao->save();
				}else{
					$this->addError('erro', Yii::t('app', 'erro.existeInfoCadastradas'));
				}
			}

			if (!$this->hasErrors())
				Yii::app()->user->setFlash('success', Yii::t('app', 'success.registroSalvoSucesso'));
			elseif($this->getError('txcondicao')){
				$this->clearErrors('txcondicao');
				$this->addError('txcondicao', Yii::t('app', 'erro.existeInfoCadastradas'));
			}

		}
	}

	private function validadeCondicao()
	{
		$data = Yii::app()->db->createCommand()
						  ->select('idcondicao, cotipopesquisa, idpesquisa')
						  ->from(Constants::SCHEMA_SINASE.'.condicao')
						  ->where('idpesquisa=:idpesquisa and txcondicao=:txcondicao ',
								  array(':idpesquisa'=>$this->idpesquisa ,
										':txcondicao'=>serialize($this->data)))
						  ->queryRow();
		return empty($data);
	}

	private function validadeFormacaoCadastral()
	{
		if (!$this->validateCreate())
			return false;

		$data = Yii::app()->db->createCommand()
							->select('idcondicao, cotipopesquisa, idpesquisa')
							->from(Constants::SCHEMA_SINASE.'.condicao')
							->where('cotipopesquisa=:coTipoPesq and idpesquisa=:idPesquisa ',
									array(':coTipoPesq'=>$this->cotipopesquisa ,
											':idPesquisa'=>$this->idpesquisa ))
							->queryRow();

		if ($data)
			$this->idcondicao = $data['idcondicao'];
	}

	private function validadeProjetoCurso()
	{
		if (!$this->validateCreate())
			return false;

	}

	private function validadePesquisaAvaliacao()
	{
		if (!$this->validateCreate())
			return false;

	}

	private function validateCreate()
	{
		$itens = 0;
		foreach ($this->data as $key => $value) {
			$itens = empty($value)?$itens:$itens+1;
		}

		if (!$this->idpesquisa)
			$this->addError('erro', Yii::t('app', 'formarTurma.naoExistePesquisaSalva'));
		if ( ($itens==0) || $this->hasErrors() ){
			if(!empty($this->idcondicao)){
				$this->preDelete($this->idcondicao);
				$this->idcondicao = null;
			}else{
				$this->addError('erro', Yii::t('app', 'erro.camposVazio'));
			}
			return false;
		}
		return true;
	}

	public function preUpdate()
	{
		return $this->save();
	}

	public function preDelete($id)
	{
		return self::model()->findByPk($id)->delete();
	}

	public function listCondicaoTipo($idpesquisa, $tipoPesquisa, $pageSize = 5)
	{
		$modelCondicao = array();
		if ($idpesquisa){
			$modelCondicao = Yii::app()->db->createCommand()
			->select('idcondicao as id, c.*')
			->from(Constants::SCHEMA_SINASE.'.condicao c')
			->where('c.idpesquisa=:idpesquisa
					and c.cotipopesquisa=:cotipopesquisa ',
					array(	':idpesquisa'=>$idpesquisa,
							':cotipopesquisa'=>$tipoPesquisa
					))
					->queryAll();
		}

		$idgrupoquestionario = array();
		$idquestionario = array();
		$idquestao = array();
		$idresposta = array();
		$idprojeto = array();
		$idcurso = array();
		$idsituacao = array();
		$notaSuperior = array();

		foreach ($modelCondicao as $key => $value) {
			$condicao = unserialize($value['txcondicao']);

			if ($tipoPesquisa == 'PAA'){
				if ($condicao['idgrupoquestionario'])
					$idgrupoquestionario[$condicao['idgrupoquestionario']] = $condicao['idgrupoquestionario'];
				if ($condicao['idquestionario'])
					$idquestionario[$condicao['idquestionario']] = $condicao['idquestionario'];
				if ($condicao['idquestao'])
					$idquestao[$condicao['idquestao']] = $condicao['idquestao'];
				if ($condicao['idresposta'])
					$idresposta[$condicao['idresposta']] = $condicao['idresposta'];
			}elseif ($tipoPesquisa == 'PCA'){
				if ($condicao['idprojeto'])
					$idprojeto[$condicao['idprojeto']] = $condicao['idprojeto'];
				if ($condicao['idcurso'])
					$idcurso[$condicao['idcurso']] = $condicao['idcurso'];
				if ($condicao['idsituacao'])
					$idsituacao[$condicao['idsituacao']] = $condicao['idsituacao'];
				if ($condicao['notaSuperior'])
					$notaSuperior[$condicao['notaSuperior']] = $condicao['notaSuperior'];
			}
		}

		$modelGrupoQuestionario = array();
		if ($idgrupoquestionario)
			$modelGrupoQuestionario = Yii::app()->db->createCommand()
			->select('idgrupoquestionario, dcgrupo')
			->from(Constants::SCHEMA_SINASE.'.grupoquestionario')
			->where('idgrupoquestionario in ('.implode(',', $idgrupoquestionario).')')
			->queryAll();

		$modelQuestionario = array();
		if ($idquestionario)
			$modelQuestionario = Yii::app()->db->createCommand()
			->select('idquestionario, dcformulario')
			->from(Constants::SCHEMA_SINASE.'.questionario')
			->where('idquestionario in ('.implode(',', $idquestionario).')')
			->queryAll();

		$modelQuestao = array();
		if ($idquestao)
			$modelQuestao = Yii::app()->db->createCommand()
			->select('idquestao, dcquestao')
			->from(Constants::SCHEMA_SINASE.'.questao')
			->where('idquestao in ('.implode(',', $idquestao).')')
			->queryAll();

		$modelResposta = array();
		if ($idresposta)
			$modelResposta = Yii::app()->db->createCommand()
			->select('idresposta, dcresposta')
			->from(Constants::SCHEMA_SINASE.'.resposta')
			->where('idresposta in ('.implode(',', $idresposta).')')
			->queryAll();

		/*
		 * PCA
		*/
		$modelProjeto = array();
		if ($idprojeto)
			$modelProjeto = Yii::app()->db->createCommand()
			->select('idprojeto, dcprojeto')
			->from(Constants::SCHEMA_SINASE.'.projeto')
			->where('idprojeto in ('.implode(',', $idprojeto).')')
			->queryAll();

		$modelCurso = array();
		if ($idcurso)
			$modelCurso = Yii::app()->db->createCommand()
			->select('id as idcurso, fullname')
			->from(Constants::SCHEMA_SINASE.'.vw_curso')
			->where('id in ('.implode(',', $idcurso).')')
			->queryAll();

		$modelCursoSituacao = array();
		if ($idcurso)
			$modelCursoSituacao = Curso::getSituacao();

		// idprojeto
		// idcurso
		// idsituacao
		// notaSuperior
		foreach ($modelCondicao as $key => $value) {
			$condicao = unserialize($value['txcondicao']);

			if ($tipoPesquisa == 'PAA'){
				$modelCondicao[$key]['dcgrupoquestionario'] = self::getArrayText($modelGrupoQuestionario,
						'idgrupoquestionario',
						$condicao['idgrupoquestionario'],
						'dcgrupo');
				$modelCondicao[$key]['dcquestionario'] = self::getArrayText($modelQuestionario,
						'idquestionario',
						$condicao['idquestionario'],
						'dcformulario');
				$modelCondicao[$key]['dcquestao'] = self::getArrayText($modelQuestao,
						'idquestao',
						$condicao['idquestao'],
						'dcquestao');
				$modelCondicao[$key]['dcresposta'] = self::getArrayText($modelResposta,
						'idresposta',
						$condicao['idresposta'],
						'dcresposta');
			}elseif ($tipoPesquisa == 'PCA'){
				$modelCondicao[$key]['dcprojeto'] = self::getArrayText($modelProjeto,
						'idprojeto',
						$condicao['idprojeto'],
						'dcprojeto');
				$modelCondicao[$key]['dccurso'] = self::getArrayText($modelCurso,
						'idcurso',
						$condicao['idcurso'],
						'fullname');
				$modelCondicao[$key]['dcsituacao'] = self::getArrayText($modelCursoSituacao,
						'idsituacao',
						$condicao['idsituacao'],
						'dcsituacao');
				$modelCondicao[$key]['notaSuperior'] = ($condicao['notaSuperior'])?$condicao['notaSuperior']:'--';
			}
		}

		return new CArrayDataProvider($modelCondicao,
				array('pagination'=>array(
						'pageSize'=>$pageSize,
				),));

	}

	private function getArrayText(array $array, $indice, $cod, $text)
	{
		foreach ($array as $key => $value){
			if ($value[$indice] == $cod)
				return $value[$text];
		}
		return '---';
	}

	public function preFind($id)
	{
		return self::model()->findByPk($id);

	}

	public function search()
	{
		return parent::search();
	}

	public function attributeLabels()
	{
		$attributes = array_merge(parent::attributeLabels(),
				array(
						//'adicioneAquiChave' => Yii::t('app', 'DescriÃ§Ã£o do label'),
				));

		return $attributes;
	}

	/*
	 // customize this function ...
	public function get_label()
	{
	return '#'.$this->id;
	}
	*/

}
