<?php

// auto-loading fix
Yii::setPathOfAlias('VwCursoTurma', dirname(__FILE__).'/base');
Yii::import('VwCursoTurma.*');

class CursoTurma extends BaseVwCursoTurma
{
	public $projeto;
	public $dtiniciocurso;
	public $dtfimcurso;
	public $userid;
	public $firstname;
	public $dtultimoacesso;
	public $dias;
	public $nome;
	public $vlnota;
	public $shortname;
	public $insituacaoalunocurso;
    public $qtselecionados;
    public $indqualitativo;

	// Add your model-specific methods here. This file will not be overriden by gtc except you force it.
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function init()
	{
		return parent::init();
	}

	public function __toString() {
		return (string) $this->courseid;

	}

	public function behaviors()
	{
		// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function rules()
	{
		return array_merge(
				array(
						array('courseid, name, description', 'required'),
						array('id',
								'required',
								'message'=>'Data final não pode ser menor que a data inicial',
								'on'=>'dash'),
				),
				parent::rules()
		);
	}

	private function existeTurma($id)
	{
		return Yii::app()->db->createCommand()
		->select('t.idturma')
		->from(Constants::SCHEMA_SINASE.'.turma t')
		->where('t.idturma=:id', array(':id'=>$id))
		->queryAll();
	}
    
    private function atualizaTabelaTurma($idturma, $qtselecionados, $indqualitativo) {
	   if (self::existeTurma($idturma))
        $sql = 'update '.Constants::SCHEMA_SINASE.'.turma set qtselecionados=:qtselecionados, indqualitativo=:indqualitativo where idturma=:idturma';
       else
        $sql = 'insert into '.Constants::SCHEMA_SINASE.'.turma(idturma, qtselecionados, indqualitativo) values (:idturma, :qtselecionados, :indqualitativo)';
       
       // Cria o objeto command
	   $command = Yii::app()->db->createCommand($sql)->execute(array(':idturma'=>$idturma,':qtselecionados'=>$qtselecionados,':indqualitativo'=>str_replace(',','.',str_replace('.','',$indqualitativo))));
	}
    
    private function excluiTabelaTurma($idturma) {
		// Cria o objeto command
		$command = Yii::app()->db->createCommand('delete from '.Constants::SCHEMA_SINASE.'.turma where idturma = '.$idturma)->execute();
    }
    
    public function preCreate()
	{
		if ($this->validate()){
			try{
				$options = array(
						'courseid' 			=> $this->courseid,
						'name'				=> $this->name,
						'description'		=> $this->description,
						'descriptionformat'	=> 1,
						//'enrolmentkey'		=> $this->visible
				);
                
                // Atualiza a tabela de turma
                self::atualizaTabelaTurma($this->idnumber, $this->qtselecionados, $this->indqualitativo);
                
				$params = array('groups' => $options);

				$WSMoodle = new WSMoodle();
				$modulo = $WSMoodle->callFunction('core_group_create_groups', array($params));
				$this->id = isset($modulo[0]['id'])?$modulo[0]['id']:$this->id;

				return $this;
			} catch (Exception $e) {
				throw new CHttpException(404, $e);
			}
		}

	}

	public function preUpdate()
	{
		try {
			if ($this->validate()){
				$options = array(
						'id' 				=> $this->id,
						'courseid' 			=> $this->courseid,
						'name'				=> $this->name,
						'description'		=> $this->description,
						'descriptionformat'	=> 1,
						//'enrolmentkey'		=> $this->visible
				);

                // Atualiza a tabela de turma
                self::atualizaTabelaTurma($this->idnumber, $this->qtselecionados, $this->indqualitativo);

				$params = array('groups' => $options);

				$WSMoodle = new WSMoodle();
				$modulo = $WSMoodle->callFunction('local_wsmymoodle_update_groups', array($params));
				$this->id = isset($modulo[0]['id'])?$modulo[0]['id']:$this->id;

				return $this;
			}
		} catch (Exception $e) {
			$message = explode("|", $e->getMessage());
			$this->addError(0, $message[0]);
		}
	}

	public function preDelete($id)
	{
		if (self::existeAlunoNaTurma($id))
			throw new CHttpException(403, Yii::t('app', 'erroDeletarTurma'));

        // Exclui na tabela de turma
        $this->excluiTabelaTurma($this->idnumber);

		$params = array('groupids' => $id);
		$WSMoodle = new WSMoodle();
		return $WSMoodle->callFunction('core_group_delete_groups', array($params));
	}

	public function preFind($id)
	{
		return self::model()->findByPk($id);
	}

	public function search()
	{
		return parent::search();
	}

	private function existeAlunoNaTurma($id)
	{
		return Yii::app()->db->createCommand()
		->select('p.id, p.groupid, p.courseid, p.userid')
		->from(Constants::SCHEMA_SINASE.'.vw_participante p')
		->where('p.groupid=:id', array(':id'=>$id))
		->queryAll();
	}

	public function attributeLabels()
	{
		return array(
				'courseid' 		 => Yii::t('app', 'curso.id'),
				'fullname' 		 => Yii::t('app', 'curso.fullname'),
				'shortname' 	 => Yii::t('app', 'curso.shortname'),
				'id' 			 => Yii::t('app', 'cursoTurma.id'),
				'idnumber' 		 => Yii::t('app', 'cursoTurma.idnumber'),
				'enrolmentkey'	 => Yii::t('app', 'cursoTurma.enrolmentkey'),
				'name' 			 => Yii::t('app', 'cursoTurma.name'),
				'description'	 => Yii::t('app', 'cursoTurma.description'),
				'format' 		 => Yii::t('app', 'cursoTurma.format'),
				'dtiniciocurso'  => Yii::t('app', 'cursoTurma.dtiniciocurso'),
				'dtfimcurso'     => Yii::t('app', 'cursoTurma.dtfimcurso'),
				'firstname'      => Yii::t('app', 'cursoTurma.firstname'),
				'dtultimoacesso' => Yii::t('app', 'cursoTurma.dtultimoacesso'),
				'vlnota'		 => Yii::t('app', 'cursoTurma.vlnota'),
                'qtselecionados' => Yii::t('app', 'cursoTurma.qtselecionados'),
                'indqualitativo' => Yii::t('app', 'cursoTurma.indqualitativo'),
		);
	}

	/*
	 // customize this function ...
	public function get_label()
	{
	return '#'.$this->id;
	}
	*/
	public function primaryKey()
	{
		return 'id';
	}

	public function gridListaTurma($data = NULL, $status = NULL, Curso $cursoObj = NULL)
	{
		$criteria=new CDbCriteria();

		$criteria->compare('vwc.shortname',$this->shortname,true);

		$criteria->alias  = 'vwct';
		$criteria->distinct = TRUE;
		$criteria->select = 'vwc.dcprojeto projeto, vwc.shortname, vwc.dtiniciocurso, vwc.dtfimcurso, vwct.name, vwct.id, vwct.qtselecionados, vwct.indqualitativo';
		$criteria->join  = ' inner join '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapelturma vwcupt on vwcupt.idturma = vwct.id';
		$criteria->join  .= ' inner join '.Constants::SCHEMA_SINASE.'.vw_curso vwc on vwcupt.id = vwc.id';

		$criteria->order = 'vwct.name';

		if($data['roleid'] == '4') {
			if (isset($data['userid']) && $data['userid']!= "") {
				$criteria->addCondition("vwcupt.userid = {$data['userid']}");
			}

			if (isset($data['roleid']) && $data['roleid']!= "") {
				$criteria->addCondition("vwcupt.roleid = {$data['roleid']}");
			}
		}

		if (isset($cursoObj->idprojeto) && $cursoObj->idprojeto != "") {
			$criteria->addCondition("vwc.idprojeto = {$cursoObj->idprojeto}");
		}

		if (isset($cursoObj->fullname) && $cursoObj->fullname != "") {
			$criteria->addCondition("vwc.id = {$cursoObj->fullname}");
		}

		if (isset($this->name) && $this->name != "") {
			$criteria->addCondition("vwcupt.idturma = {$this->name}");
		}

		if (isset($status)) {
			$curso = new Curso();

			$curso->dtiniciocurso = (!empty($this->dtiniciocurso))
			?date('Y-m-d', CDateTimeParser::parse($this->dtiniciocurso, Yii::app()->locale->getDateFormat('medium')))
			:NULL;

			$curso->dtfimcurso = (!empty($this->dtfimcurso))
			?date('Y-m-d', CDateTimeParser::parse($this->dtfimcurso, Yii::app()->locale->getDateFormat('medium')))
			:NULL;

			switch ($status) {
				case 'andamento':
					$curso->criteriaAndamento($criteria);
					break;
				case 'finalizado':
					$curso->criteriaFinalizado($criteria);
					break;
				case 'aberto':
					$curso->criteriaAberto($criteria, FALSE);
					break;
			}


		}

		return $criteria;

	}

	public function alunoTurmaDiasSemAcessar($idTurma, $qtdDias = 1)
	{
		$criteria=new CDbCriteria();

		$criteria->alias = 'ct';
		$criteria->select = "cua.userid, upper(cup.firstname) as firstname, cua.dtultimoacesso, DATE_PART('day', now()::timestamp - dtultimoacesso::timestamp) as dias";
		$criteria->join  = 'inner join '.Constants::SCHEMA_SINASE.'.vw_participante as par on (par.courseid = ct.courseid and par.groupid = ct.id) ';
		$criteria->join .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_cursousuarioacesso cua on cua.course = par.courseid and cua.userid = par.userid ';
		$criteria->join .= 'inner join '.Constants::SCHEMA_SINASE.'.usuario as usu on (usu.idmoodle = par.userid) ';
		$criteria->join .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle';

		$criteria->addCondition("ct.id = {$idTurma}");
		$criteria->addCondition("DATE_PART('day', now()::timestamp - dtultimoacesso::timestamp) >= {$qtdDias}");

		$criteria->addCondition("cup.roleid = ".Constants::MOODLE_ROLE_TYPE_ENROL);


		return $criteria;

	}

	public function getEmailUsuarios($idUsuarios)
	{
		$criteria=new CDbCriteria();

		$criteria->alias  = 'ct';
		$criteria->select = 'dcemail';
		$criteria->join   = 'inner join '.Constants::SCHEMA_SINASE.'.vw_participante par on par.courseid = ct.courseid and par.groupid = ct.id ';
		$criteria->join  .= 'inner join '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid ';
		$criteria->addInCondition('usu.idmoodle', $idUsuarios);

		return CursoTurma::model()->findAll($criteria);
	}

	public function alunosTurma($idTurma)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
        ->setText('SELECT usu.idusuario as userid, usu.dcnome as nome
        	         FROM '.Constants::SCHEMA_SINASE.'.vw_cursoturma ct
        	        INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id)
        	        INNER JOIN '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid
        	        INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle
        	        INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle
        	        WHERE cup.roleid = '.Constants::MOODLE_ROLE_TYPE_ENROL.'
        	          AND ct.id = '.$idTurma.'
        	        ORDER BY usu.dcnome');
		// Retorna o resultado da Query
        return $command->queryAll();
	}
    
    public function notasAlunoTurma($idTurma)
	{
		$criteria = new CDbCriteria();

		$criteria->alias   = 'ct';
		$criteria->select  = "usu.idusuario as userid, vwnt.vlnota, usu.dcnome as nome";
		$criteria->join    = 'inner join '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id) ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle ';
		$criteria->addCondition("cup.roleid = ".Constants::MOODLE_ROLE_TYPE_ENROL);
		$criteria->addCondition("ct.id = ".$idTurma);
		$criteria->order = 'usu.dcnome';

		return $criteria;
	}

	public function alunoTurmaAprovar($idTurma, $nota = NULL, $status = NULL)
	{
		$criteria=new CDbCriteria();

		$criteria->alias  = 'ct';
		$criteria->distinct = TRUE;
		$criteria->select = "ct.id, usu.idusuario as userid, usu.dcnome as nome, vwnt.vlnota, c.insituacaoalunocurso";
		$criteria->join   = 'inner join '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id) ';
		$criteria->join  .= 'inner join '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle ';
		$criteria->join   .= 'inner join '.Constants::SCHEMA_SINASE.'.controleinscricao c on c.idcursomoodle = vwnt.courseid and c.idturma = par.groupid and c.idusuario = usu.idusuario';
		$criteria->addCondition("ct.id = {$idTurma}");

		if (isset($nota) && is_numeric($nota)) {
			$criteria->addCondition("vwnt.vlnota >= {$nota}");
		}

		if(isset($status)) {
			$criteria->addCondition("c.insituacaoalunocurso = '{$status}'");
		}

		$criteria->addCondition("cup.roleid = ".Constants::MOODLE_ROLE_TYPE_ENROL);
		$criteria->order = 'usu.dcnome';

		return $criteria;

	}

	public function dadosCursoTurma($idTurma)
	{
		$select = Yii::app()->db->createCommand();

		return $select->select('c.dtinicio, c.dtfinal, c.dcprojeto, c.shortname, ct.name')
		->from(Constants::SCHEMA_SINASE.'.vw_curso c')
		->join(Constants::SCHEMA_SINASE.'.vw_cursoturma ct','ct.courseid = c.id')
		->where('ct.id=:idturma', array(':idturma'=>$idTurma))
		->queryRow();

	}

	public function gridIndicador1($status = NULL, Curso $cursoObj = NULL)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
		->select('t3.idprojeto as projeto, t2.couf as uf, count(*) as qtd, round(avg(t1.vlnota),2) as media')
		->from(Constants::SCHEMA_SINASE.'.vw_notacurso t1')
		->join(Constants::SCHEMA_SINASE.'.usuario t2','t1.userid = t2.idusuario')
		->join(Constants::SCHEMA_SINASE.'.projetocurso t3','t1.courseid = t3.idcursomoodle');
		// Verifica se está filtrando pelo projeto
		if (isset($cursoObj->idprojeto) && $cursoObj->idprojeto != '') {
			$command->andWhere('t3.idprojeto = :idprojeto',array(':idprojeto'=>$cursoObj->idprojeto));
		}
		// Verifica se está filtrando pelo curso
		if (isset($cursoObj->fullname) && $cursoObj->fullname != "") {
			$command->andWhere('t1.courseid = :idcurso',array(':idcurso'=>$cursoObj->fullname));
		}
		// Verifica se está filtrando pelo status
		if (isset($status) && $status != "") {
			switch ($status) {
				case 'andamento':
					$command->andWhere('now()::date BETWEEN t3.dtiniciocurso::date AND t3.dtfimcurso::date');
					break;
				case 'finalizado':
					$command->andWhere('now()::date BETWEEN t3.dtinicioinscricao::date AND t3.dtfiminscricao::date');
					break;
				case 'aberto':
					$command->andWhere('t3.dtfimcurso::date < now()::date');
					break;
			}
		}
		// Incluir a clausula de Group By
		$command->group('projeto, uf');
		// Incluir a clausula de Order By
		$command->order('uf');
		// Retorna o resultado da Query
        return new CArrayDataProvider($command->queryAll(), array('keyField'=>'uf',	'pagination' => array('pageSize' => 27,)));
    }

	public function gridIndicador1Total($status = NULL, Curso $cursoObj = NULL)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
		->select('count(*) as qtd')
		->from(Constants::SCHEMA_SINASE.'.vw_notacurso t1')
		->join(Constants::SCHEMA_SINASE.'.usuario t2','t1.userid = t2.idusuario')
		->join(Constants::SCHEMA_SINASE.'.projetocurso t3','t1.courseid = t3.idcursomoodle');
		// Verifica se está filtrando pelo projeto
		if (isset($cursoObj->idprojeto) && $cursoObj->idprojeto != '') {
			$command->andWhere('t3.idprojeto = :idprojeto',array(':idprojeto'=>$cursoObj->idprojeto));
		}
		// Verifica se está filtrando pelo curso
		if (isset($cursoObj->fullname) && $cursoObj->fullname != "") {
			$command->andWhere('t1.courseid = :idcurso',array(':idcurso'=>$cursoObj->fullname));
		}
		// Verifica se está filtrando pelo status
		if (isset($status) && $status != "") {
			switch ($status) {
				case 'andamento':
					$command->andWhere('now()::date BETWEEN t3.dtiniciocurso::date AND t3.dtfimcurso::date');
					break;
				case 'finalizado':
					$command->andWhere('now()::date BETWEEN t3.dtinicioinscricao::date AND t3.dtfiminscricao::date');
					break;
				case 'aberto':
					$command->andWhere('t3.dtfimcurso::date < now()::date');
					break;
			}
		}
		// Retorna o resultado da Query
        return $command->queryScalar();
    }
    
	public function gridIndicador1Detalhe($status = NULL, Curso $cursoObj = NULL, $uf = NULL)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
		->select('t3.idprojeto as projeto, t2.couf as uf, t2.dccidade as cidade, count(*) as qtd, round(avg(t1.vlnota),2) as media')
		->from(Constants::SCHEMA_SINASE.'.vw_notacurso t1')
		->join(Constants::SCHEMA_SINASE.'.usuario t2','t1.userid = t2.idusuario')
		->join(Constants::SCHEMA_SINASE.'.projetocurso t3','t1.courseid = t3.idcursomoodle');
		//->where('p.groupid=:id', array(':id'=>$id))
		// Verifica se está filtrando pelo projeto
		if (isset($cursoObj->idprojeto) && $cursoObj->idprojeto != '') {
			$command->andWhere('t3.idprojeto = :idprojeto',array(':idprojeto'=>$cursoObj->idprojeto));
		}
		// Verifica se está filtrando pelo curso
		if (isset($cursoObj->fullname) && $cursoObj->fullname != "") {
			$command->andWhere('t3.courseid = :idcurso',array(':idcurso'=>$cursoObj->fullname));
		}
		// Verifica se está filtrando pelo status
		if (isset($status) && $status != "") {
			switch ($status) {
				case 'andamento':
					$command->andWhere('now()::date BETWEEN t3.dtiniciocurso::date AND t3.dtfimcurso::date');
					break;
				case 'finalizado':
					$command->andWhere('now()::date BETWEEN t3.dtinicioinscricao::date AND t3.dtfiminscricao::date');
					break;
				case 'aberto':
					$command->andWhere('t3.dtfimcurso::date < now()::date');
					break;
			}
		}
		// Verifica se está filtrando pelo curso
		if (isset($uf) && $uf != "") {
			$command->andWhere('t2.couf = :uf',array(':uf'=>$uf));
		}
		// Incluir a clausula de Group By
		$command->group('projeto, uf, cidade');
		// Incluir a clausula de Order By
		$command->order('cidade');
		// Retorna o resultado da Query
		return $command->queryAll();

	}

	public function gridIndicador1DetalheTotal($status = NULL, Curso $cursoObj = NULL, $uf = NULL)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
		->select('count(*) as qtd')
		->from(Constants::SCHEMA_SINASE.'.vw_notacurso t1')
		->join(Constants::SCHEMA_SINASE.'.usuario t2','t1.userid = t2.idusuario')
		->join(Constants::SCHEMA_SINASE.'.projetocurso t3','t1.courseid = t3.idcursomoodle');
		//->where('p.groupid=:id', array(':id'=>$id))
		// Verifica se está filtrando pelo projeto
		if (isset($cursoObj->idprojeto) && $cursoObj->idprojeto != '') {
			$command->andWhere('t3.idprojeto = :idprojeto',array(':idprojeto'=>$cursoObj->idprojeto));
		}
		// Verifica se está filtrando pelo curso
		if (isset($cursoObj->fullname) && $cursoObj->fullname != "") {
			$command->andWhere('t3.courseid = :idcurso',array(':idcurso'=>$cursoObj->fullname));
		}
		// Verifica se está filtrando pelo status
		if (isset($status) && $status != "") {
			switch ($status) {
				case 'andamento':
					$command->andWhere('now()::date BETWEEN t3.dtiniciocurso::date AND t3.dtfimcurso::date');
					break;
				case 'finalizado':
					$command->andWhere('now()::date BETWEEN t3.dtinicioinscricao::date AND t3.dtfiminscricao::date');
					break;
				case 'aberto':
					$command->andWhere('t3.dtfimcurso::date < now()::date');
					break;
			}
		}
		// Verifica se está filtrando pelo curso
		if (isset($uf) && $uf != "") {
			$command->andWhere('t2.couf = :uf',array(':uf'=>$uf));
		}
		// Retorna o resultado da Query
		return $command->queryScalar();
	}

	public function notasAlunoTurmaPlanilha($turma)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
        ->setText('WITH
                      alunos AS (SELECT usu.idusuario as userid, usu.dcnome as nome
                    	       FROM '.Constants::SCHEMA_SINASE.'.vw_cursoturma ct
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id)
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle
                    	      WHERE cup.roleid = '.Constants::MOODLE_ROLE_TYPE_ENROL.'
                    	        AND ct.id = '.$turma.'
                    	      ORDER BY usu.dcnome),
                      notas_questionarios AS (SELECT userid, sum(vlnota) AS nota 
                    			    FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade 
                    			   WHERE tpmodulo = \'quiz\'  
                    			     AND userid in (SELECT userid FROM alunos) 
                    			   GROUP BY userid),
                      notas_foruns AS (SELECT userid, sum(vlnota) AS nota 
                    		     FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade 
                    		    WHERE tpmodulo = \'forum\' 
                    		      AND userid in (SELECT userid FROM alunos) 
                    		    GROUP BY userid)
                    SELECT 	a.userid, a.nome,
                    	COALESCE(q.nota, 0.00000) AS nota_questionario, 
                    	COALESCE(f.nota, 0.00000) AS nota_forum,
                    	COALESCE((q.nota + f.nota)/2, 0.00000) AS media_parcial,
                    	retorna_mencao(COALESCE((q.nota + f.nota)/2, 0.00000)) AS mencao_parcial,
                    	COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000) AS trabalho_final,
                    	(COALESCE((q.nota + f.nota)/2, 0.00000) + (COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000))) AS pontuacao_final,
                    	retorna_mencao((COALESCE((q.nota + f.nota)/2, 0.00000) + (COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000)))) AS mencao_final
                      FROM alunos a
                      LEFT JOIN notas_questionarios q ON a.userid = q.userid
                      LEFT JOIN notas_foruns f ON a.userid = f.userid
                     ORDER BY a.nome');
        // Pontuação final comentada com média
        // (COALESCE((q.nota + f.nota)/2, 0.00000) + (COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000) * 2))/3 AS pontuacao_final,
        // retorna_mencao((COALESCE((q.nota + f.nota)/2, 0.00000) + (COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000) * 2))/3) AS mencao_final
		// Retorna o resultado da Query
        return new CArrayDataProvider($command->queryAll(), array('keyField'=>'userid',	'pagination' => FALSE));
    }

	public function indicadoresAlunoTurma($turma)
	{
		// Cria o objeto command
		$command = Yii::app()->db->createCommand()
        ->setText('WITH
                      alunos AS (SELECT usu.idusuario as userid, usu.dcnome as nome
                    	       FROM '.Constants::SCHEMA_SINASE.'.vw_cursoturma ct
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id)
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle
                    	      WHERE cup.roleid = '.Constants::MOODLE_ROLE_TYPE_ENROL.'
                    	        AND ct.id = '.$turma.'
                    	      ORDER BY usu.dcnome),
                      notas_questionarios AS (SELECT userid, sum(vlnota) AS nota 
                    			    FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade 
                    			   WHERE tpmodulo = \'quiz\'  
                    			     AND userid in (SELECT userid FROM alunos) 
                    			   GROUP BY userid),
                      notas_foruns AS (SELECT userid, sum(vlnota) AS nota 
                    		     FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade 
                    		    WHERE tpmodulo = \'forum\' 
                    		      AND userid in (SELECT userid FROM alunos) 
                    		    GROUP BY userid),
                      mencao AS (SELECT a.userid, retorna_mencao((COALESCE((q.nota + f.nota)/2, 0.00000) + (COALESCE((SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade c WHERE c.tpmodulo = \'assignment\' AND c.dctarefa ILIKE \'%final%\'  AND c.userid = a.userid LIMIT 1), 0.00000) * 2))/3) AS mencao_final
                              FROM alunos a
                              LEFT JOIN notas_questionarios q ON a.userid = q.userid
                              LEFT JOIN notas_foruns f ON a.userid = f.userid)
                     SELECT (SELECT count(1) FROM mencao) AS qtde_no_ambiente, 
                        	(SELECT count(1) FROM mencao WHERE mencao_final = \'SR\') AS qtde_abandonos_sr,
                        	(SELECT count(1) FROM mencao WHERE mencao_final = \'II\') AS qtde_capacitados_ii,
                        	(SELECT count(1) FROM mencao WHERE mencao_final = \'MI\') AS qtde_capacitados_mi,
                        	(SELECT count(1) FROM mencao WHERE mencao_final IN (\'MM\',\'MS\',\'SS\')) AS qtde_certificados');
		// Retorna o resultado da Query
        return $command->queryRow();
    }

	public function notasAlunosTurma($curso,$tipo,$usuario)
	{
		// Cria o objeto command
        /*->setText('WITH
                      alunos AS (SELECT usu.idusuario as userid, usu.dcnome as nome
                    	       FROM '.Constants::SCHEMA_SINASE.'.vw_cursoturma ct
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_participante par on (par.courseid = ct.courseid and par.groupid = ct.id)
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.usuario usu on usu.idmoodle = par.userid
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_cursousuariopapel cup on cup.userid = usu.idmoodle
                    	      INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_notacurso vwnt on vwnt.courseid = par.courseid and vwnt.userid = usu.idmoodle
                    	      WHERE cup.roleid = '.Constants::MOODLE_ROLE_TYPE_ENROL.'
                    	        AND ct.id = '.$turma.'
                                AND usu.idusuario = '.$usuario.'
                    	      ORDER BY usu.dcnome)
                     SELECT idtarefa, vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade
                      WHERE userid in (SELECT userid FROM alunos)
                        AND tpmodulo = \''.$tipo.'\'
                      ORDER BY idtarefa');*/
		$command = Yii::app()->db->createCommand()
        ->setText('SELECT A.'.($tipo=='quiz'?'idquestionario':'idforum').', (SELECT vlnota FROM '.Constants::SCHEMA_SINASE.'.vw_notaatividade B
                   WHERE A.idcurso = B.idcurso AND A.idmodulo = B.idmodulo AND A.nummodulo = B.nummodulo 
                     AND B.userid = '.$usuario.' AND B.tpmodulo = \''.$tipo.'\') AS vlnota
                    FROM '.Constants::SCHEMA_SINASE.'.vw_curso'.($tipo=='quiz'?'questionario':'forum').' A
                   WHERE A.idcurso = '.$curso.' ORDER BY A.idmodulo');
		// Retorna o resultado da Query
        return $command->queryAll();
    }
    
    public function qtdeAtividades($curso,$tipo){
		$command = Yii::app()->db->createCommand()
        ->setText('SELECT COUNT(1) FROM '.Constants::SCHEMA_SINASE.'.vw_curso'.($tipo=='quiz'?'questionario':'forum').'
                   WHERE idcurso = '.$curso);
		// Retorna o resultado da Query
        return $command->queryScalar();
    }
}