<?php

// auto-loading fix
Yii::setPathOfAlias('Email', dirname(__FILE__).'/base');
Yii::import('Email.*');

/**
 * @author sinase
 *
 */
class Email extends BaseEmail
{
	public $dcemailtipoenvio = null;
	public $assunto = null;

	// Add your model-specific methods here. This file will not be overriden by gtc except you force it.
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function init()
	{
		return parent::init();
	}

	public function __toString() {
		return (string) $this->dctitulo;
	}

	public function behaviors()
	{
		// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function rules()
	{
		return array_merge(
				array(
						// THIS IS THE NEW STUFF
						//array('dcsenha', 'length', 'min'=>6, 'max'=>30),
				),
				parent::rules()
		);
	}

	public function preCreate()
	{
		return $this->save();
	}

	public function preUpdate()
	{
		return $this->save();
	}

	public function preDelete($id)
	{
		return self::model()->findByPk($id)->delete();
	}

	public function preFind($id)
	{
		return self::model()->findByPk($id);
	}

	public function search()
	{
		return parent::search();
	}

	public function listEmail()
	{
		$criteria=new CDbCriteria;

		$criteria->alias = 'e';
		$criteria->select = 'e.idemail, e.dctitulo, e.dccorpoemail, e.inativo,
		ete.idemailtipoenvio, ete.dcemailtipoenvio';
		$criteria->join = 'left join '.Constants::SCHEMA_SINASE.'.emailtipoenvio ete on
		e.idemailtipoenvio = ete.idemailtipoenvio';
		$criteria->compare('e.idemail', $this->idemail);
		$criteria->compare('e.idemailtipoenvio', $this->idemailtipoenvio);
		$criteria->compare('e.dctitulo', $this->dctitulo, true);
		$criteria->compare('e.dccorpoemail', $this->dccorpoemail, true);
		$criteria->compare('e.inativo', $this->inativo);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function attributeLabels()
	{
		$attributes = array_merge(parent::attributeLabels(),
				array(
						'inativo' => Yii::t('app', 'generic.inativo'),
						'idemail' => Yii::t('app', 'generic.id'),
						'dcemailtipoenvio' => Yii::t('app', 'email.dcemailtipoenvio'),
						'assunto' => Yii::t('app', 'generic.assunto'),
				));

		return $attributes;
	}

	/**
	 * @param integer $idEmail
	 */
		public function testEmail($idEmail)
		{
			$usuario = Yii::app()->db->createCommand()
					->select('u.idusuario, u.dcnome, u.dcemail,')
					->from(Constants::SCHEMA_SINASE.'.usuario u')
					->where('u.idusuario=:idusuario',
							array(':idusuario'=>Yii::app()->user->id))
							->queryRow();

			$mailTo = array($usuario['dcemail']=>$usuario['dcnome']);

			$email = Yii::app()->db->createCommand()
					->select('e.*')
					->from(Constants::SCHEMA_SINASE.'.email e')
					->where('e.idemail=:idemail',
							array(':idemail'=>$idEmail))
							->queryRow();

			$usuarios = Yii::app()->db->createCommand()
						->select("u.idusuario, u.dcnome, u.dcemail, pa.coperfilacesso, pa.dcperfilacesso")
						->from(Constants::SCHEMA_SINASE.'.usuario u')
						->join(Constants::SCHEMA_SINASE.'.usuarioperfilacesso upa', 'u.idusuario = upa.idusuario')
						->join(Constants::SCHEMA_SINASE.'.perfilacesso pa', 'upa.coperfilacesso = pa.coperfilacesso');

			/*
			 * Prepara a consulta conforme o tipo de envio,
		 	 * cadastrado nas configurações do email.
		 	 */
			switch ($email['idemailtipoenvio']) {
				case 1: // "Todos os alunos ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso',
											array(':coperfilacesso'=>'aluno'));
					break;
				case 2: // "Todos os supervisores ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso',
									array(':coperfilacesso'=>'superv'));
					break;
				case 3: // "Todos os tutores ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso',
									array(':coperfilacesso'=>'tutor'));
					break;
				case 4: // "Todos os usuários ativos do sistema"
					$usuarios->where('u.idusuariostatus=1');
					break;
				case 5: // "Todos os alunos inativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso and u.idusuariostatus=3',
									array(':coperfilacesso'=>'aluno'));
					break;
				case 6: // "Todos os usuários inativos do sistema"
					$usuarios->where('u.idusuariostatus=3');
					break;
				case 7: // "Somente um aluno do sistema"
				case 8: // "Somente um supervisor do sistema"
				case 9: // "Somente um tutor do sistema"
				case 10: // "Somente um usuário do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso',
									array(':coperfilacesso'=>'aluno'));
					break;
				case 11: // "Usuário sem vinculo com o sistema"
					throw new CHttpException(404, Yii::t('app', 'erro.tipoDeEnvioInvalido'));
					break;
				default:
					break;
			}

			$query = $usuarios->queryRow();
			return self::preSendMail($idEmail, $query['idusuario'], $mailTo);
		}

	public function preSendMail($idEmail,
								$idUsuario = null,
								array $mailTo = array(),
								$idCurso = null)
	{
		$url = array();

		$email = Yii::app()->db->createCommand()
				->select('e.*')
				->from(Constants::SCHEMA_SINASE.'.email e')
				->where('e.idemail=:idemail',
						array(':idemail'=>$idEmail))
				->queryRow();

		$tagValue = array();

		switch ($email['idemailtipoenvio']) {
			case 1:
				break;
			case 2:
				break;
			case 3:
				break;
			case 4:
				break;
			case 5:
				break;
			case 6:
				break;
			case 7:
			case 8:
			case 9:
			case 10:
				if ($idUsuario){
					$usuario = Yii::app()->db->createCommand()
							->select("u.idusuario, u.dcnome, u.dtnascimento, u.nutelefoneparticular, u.nutelefonecelular,
									u.dcemail, u.nutelefonecomercial,
									u.dcendereco, u.nuendereco, u.dccomplemento, u.couf, u.dcbairro, u.dccidade, u.nucep,
									(u.dcendereco || ' - ' || u.nuendereco || ' (' || u.dccomplemento ||') ' || '\n' || u.dccidade || '('|| u.couf || ')' || '\n' || 'CEP:' ||u.nucep
									|| ' '|| u.dcbairro) as dcenderecocompleto,
									u.dccurriculolattes, u.dcusuario, u.dcsenha, u.dtcadastro")
							->from(Constants::SCHEMA_SINASE.'.usuario u')
							->where('u.idusuario=:idusuario',
									array(':idusuario'=>$idUsuario))
							->queryRow();

					$perfil['perfil'] = Yii::app()->db->createCommand()
							->select("pa.coperfilacesso, pa.dcperfilacesso")
							->from(Constants::SCHEMA_SINASE.'.usuario u')
							->join(Constants::SCHEMA_SINASE.'.usuarioperfilacesso upa', 'u.idusuario = upa.idusuario')
							->join(Constants::SCHEMA_SINASE.'.perfilacesso pa', 'upa.coperfilacesso = pa.coperfilacesso')
							->where('u.idusuario=:idusuario',
									array(':idusuario'=>$idUsuario))
							->queryAll();

					$mailTo = $mailTo?$mailTo:array($usuario['dcemail']=>$usuario['dcnome']);

					$tagValue = array_merge($usuario, $perfil);

					if ($idCurso && in_array($idEmail, array(7,8,9))){
						$Curso = new Curso();
						$curso = $Curso->getCursos($idCurso);
						$tagValue = array_merge($tagValue, $curso);
					}

				if ($usuario && in_array($idEmail, array(1,3,5))){
						$Usuario = new Usuario();
						$url = array("token"=>$Usuario->gerarTokenUsuario($usuario['dcemail']));
					}
				}
				break;
			default:
				break;
		}

		$portal = Yii::app()->db->createCommand()
					->select('pc.idportalconfig, pc.txtmailtopo, pc.txmailrodape,')
					->from(Constants::SCHEMA_SINASE.'.portalconfig pc')
					->where('pc.inativo=:inativo', array(':inativo'=>1))
					->queryRow();

		if (!$portal)
			throw new CHttpException(404, Yii::t('app', 'erro.configuracaoNaoExiste'));
		/*
		 * Todas as funções do php deve retornar o
		* valor para estrutura abaixo.
		*/
		$tagFunction = array(
				'timer' 				=> date("H:i:s"),
				'date' 					=> date("d-m-Y"),
				'dateTimer' 			=> date("d-m-Y H:i:s"),
				'linkHrefConfirmacao'	=> "<a href='".Yii::app()->createAbsoluteUrl("usuario/confirmarCadastro", $url)."' target='_blank'>".Yii::t('app', 'generic.clickAqui')."</a>",
				'linkConfirmacao'		=> Yii::app()->createAbsoluteUrl("usuario/confirmarCadastro", $url),
				'linkHrefRecuperarSenha'=> "<a href='".Yii::app()->createAbsoluteUrl("site/loginRecoverConfirm", $url)."' target='_blank'>".Yii::t('app', 'generic.clickAqui')."</a>",
				'linkRecuperarSenha'	=> Yii::app()->createAbsoluteUrl("site/loginRecoverConfirm", $url),
				'urlPortal'				=>  Yii::app()->createAbsoluteUrl('/'),
				'cabecalho'				=> $portal['txtmailtopo'],
				'rodape'				=> $portal['txmailrodape']
		);

		$tagValue = array_merge($tagValue, $tagFunction);
		$mensagem = self::prepareEmailBody($email, $tagValue);

		return self::sendMail($email['dctitulo'],
							  $mensagem,
							  $email['idemailtipoenvio'],
							  $idUsuario,
							  $mailTo);
	}

	/**
	 * Prepare o corpo do email para envio
	 * @param array not null $email
	 * @param array not null $tagValue
	 */
	private function prepareEmailBody(array $email, array $tagValue)
	{
		$emailtag = Yii::app()->db->createCommand()
				->select('et.*')
				->from(Constants::SCHEMA_SINASE.'.emailtag et')
				->join(Constants::SCHEMA_SINASE.'.emailgrupotag egt', 'et.idemailtag = egt.idemailtag')
				->where('egt.idemail=:idemail and et.inativo=1',
						array(':idemail'=>$email['idemail']))
				->queryAll();

		$tipoTag = array(
				1=>'preTextoAtribBD',
				2=>'preTextoFuncPHP',
				3=>'preTextoFuncAPP',
		);

		$mensagem 	= $email['dccorpoemail'];

		foreach ($emailtag as $key => $value) {
			$mensagem = self::$tipoTag[$value['idemailtipotag']]($mensagem, $value, $tagValue);
		}

		return $mensagem;
	}

	private function preTextoAtribBD($mensagem, $value, $tagFunction)
	{
// 		if (isset($tagFunction[$value['dcemailtagreplace']]) && is_array($tagFunction[$value['dcemailtagreplace']])){
		if (isset($tagFunction[$value['dcemailtagreplace']]) ){
			if(is_array($tagFunction[$value['dcemailtagreplace']])) {
				$tag = '';
				foreach ($tagFunction[$value['dcemailtagreplace']] as $key => $valuePerfil) {
					$tag .= implode($valuePerfil, '-')."<br>";
				}
				$tagFunction[$value['dcemailtagreplace']] = $tag;
			}

			if(in_array($value['dcemailtag'], array('[data-inicio-turma]',
					                   '[data-final-turma]',
					                   '[data-inicio-inscricao]',
					                   '[data-final-inscricao]')))
			{
				$tagFunction[$value['dcemailtagreplace']] = date('d/m/Y',strtotime($tagFunction[$value['dcemailtagreplace']]));
			}

			return str_replace($value['dcemailtag'], $tagFunction[$value['dcemailtagreplace']], $mensagem);
		}
		return $mensagem;
			}

	private function preTextoFuncPHP($mensagem, $value, $tagFunction)
	{
		return str_replace($value['dcemailtag'], $tagFunction[$value['dcemailtagreplace']], $mensagem);
	}

	private function preTextoFuncAPP($mensagem, $value, $tagFunction)
	{
		return $mensagem;
	}

	/**
	 * Manda email para os usuários do sistema
	 * conforme $tipoEnvio
	 * @param string not null$titulo
	 * @param text not null $mensagem
	 * @param integer not null $tipoEnvio
	 * @param integer null $idUsuario
	 */
	public function sendMail($titulo,
							 $mensagem,
							 $tipoEnvio,
							 $idUsuario = null,
							 array $mailTo = array() )
	{

		if (!count($mailTo))
		{
			$usuarios = Yii::app()->db->createCommand()
						->select("u.idusuario, u.dcnome, u.dcemail, pa.coperfilacesso, pa.dcperfilacesso")
						->from(Constants::SCHEMA_SINASE.'.usuario u')
						->join(Constants::SCHEMA_SINASE.'.usuarioperfilacesso upa', 'u.idusuario = upa.idusuario')
						->join(Constants::SCHEMA_SINASE.'.perfilacesso pa', 'upa.coperfilacesso = pa.coperfilacesso');

			/*
			 * Prepara a consulta conforme o tipo de envio,
			* cadastrado nas configurações do email.
			*/
			switch ($tipoEnvio) {
				case 1: // "Todos os alunos ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso and u.idusuariostatus=1',
					array(':coperfilacesso'=>'aluno'));
					break;
				case 2: // "Todos os supervisores ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso and u.idusuariostatus=1',
					array(':coperfilacesso'=>'superv'));
					break;
				case 3: // "Todos os tutores ativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso and u.idusuariostatus=1',
					array(':coperfilacesso'=>'tutor'));
					break;
				case 4: // "Todos os usuários ativos do sistema"
					$usuarios->where('u.idusuariostatus=1');
					break;
				case 5: // "Todos os alunos inativos do sistema"
					$usuarios->where('pa.coperfilacesso=:coperfilacesso and u.idusuariostatus=3',
					array(':coperfilacesso'=>'aluno'));
					break;
				case 6: // "Todos os usuários inativos do sistema"
					$usuarios->where('u.idusuariostatus=3');
					break;
				case 7: // "Somente um aluno do sistema"
				case 8: // "Somente um supervisor do sistema"
				case 9: // "Somente um tutor do sistema"
				case 10: // "Somente um usuário do sistema"
					$usuarios->where('u.idusuario=:idusuario',
					array(':idusuario'=>$idUsuario));
					break;
				case 11: // "Usuário sem vinculo com o sistema"
					throw new CHttpException(404, Yii::t('app', 'erro.tipoDeEnvioInvalido'));
					break;
				default:
					break;
			}
			$query = $usuarios->queryAll();

			foreach ($query as $key => $value) {
				$mailTo[$value['dcemail']] = $value['dcnome'];
			}
		}

		if (count($mailTo)){
			$MailApp = new MailApp();
			$MailApp->to = $mailTo;
			$MailApp->subject = $titulo;
			$MailApp->body = $mensagem;
			$MailApp->send();
			return true;
		}

		throw new CHttpException(404, Yii::t('app', 'erro.infInsuficienteEmail'));
	}

	/*
	 // customize this function ...
	public function get_label()
	{
	return '#'.$this->id;
	}
	*/

	}
