<?php

/**
 * LoginForm class.
 * LoginForm is the data structure for keeping
 * user login form data. It is used by the 'login' action of 'SiteController'.
 */
class LoginForm extends CFormModel
{
	public $username;
	public $password;
	public $passwordNew;
	public $passwordNewConfirm;
	public $rememberMe;
	public $emailLoginRecover;
	PUBLIC $inRecuperarAcesso;

	private $_identity;

	/**
	 * Declares the validation rules.
	 * The rules state that username and password are required,
	 * and password needs to be authenticated.
	 */
	public function rules()
	{
		// 		XDebug::x($this->getScenario());
		return array(
				// username and password are required
				array('username, password', 'required', 'on'=>array('login', 'search')),
				array('emailLoginRecover, inRecuperarAcesso', 'required', 'on'=>'recover'),
				// rememberMe needs to be a boolean
				array('rememberMe', 'boolean'),
				array('username, password', 'safe'),
				// password needs to be authenticated
				array('password', 'authenticate', 'on'=>'login'),
		);
	}

	/**
	 * Declares attribute labels.
	 */
	public function attributeLabels()
	{
		return array(
				'rememberMe'=>'Lembrar o acesso na próxima vez',
				'emailLoginRecover'=>'Email para recuperar informações de acesso',
				'inRecuperarAcesso'=>'Tipo de recuperação',
		);
	}

	/**
	 * Authenticates the password.
	 * This is the 'authenticate' validator as declared in rules().
	 */
	public function authenticate($attribute,$params)
	{
		if(!$this->hasErrors())
		{
			$this->_identity=new UserIdentity($this->username,$this->password);
			if($erro = !$this->_identity->authenticate()){
				$this->addError('password', Yii::app()->user->getFlash('erro'));
			}
		}
	}

	/**
	 * Logs in the user using the given username and password in the model.
	 * @return boolean whether login is successful
	 */
	public function login()
	{
		$this->setScenario('login');

		if($this->_identity===null)
		{
			$this->_identity=new UserIdentity($this->username, $this->password);
			$this->_identity->authenticate();
		}

		if($this->_identity->errorCode===UserIdentity::ERROR_NONE)
		{
			$duration=$this->rememberMe ? 3600*24*30 : 0; // 30 days
			Yii::app()->user->login($this->_identity, $duration);
			return true;
		}
		else
			return false;
	}

	/**
	 * Logs in the user using the given username and password in the model.
	 * @return boolean whether login is successful
	 */
	public function loginRecover()
	{
		$this->setScenario('recover');

		if(!$this->_identity===null)
		{
			Yii::app()->user->setFlash('erro', Yii::t('app', 'erro.desconhecido'));
			return false;
		}

		if ($this->validate())
		{
			$Usuario = new Usuario();
			$usuario = $Usuario->existeUsuario($this->emailLoginRecover);

			if ( !$usuario ){
				Yii::app()->user->setFlash('erro', Yii::t('app', 'login.informeEmailValido'));
				return false;
			}elseif($usuario['idusuariostatus']==2 && $this->inRecuperarAcesso==1){
				Yii::app()->user->setFlash('erro', Yii::t('app', 'login.cadastroNaoAtivado'));
				return false;
			}elseif($usuario['idusuariostatus']!=2 && $this->inRecuperarAcesso==2){
				Yii::app()->user->setFlash('erro', Yii::t('app', 'login.codigoAcessoJaLiberado'));
				return false;
			}elseif($usuario['idusuariostatus']==4){
				Yii::app()->user->setFlash('erro', Yii::t('app', 'login.acessoBloqueado'));
				return false;
			}

			$Email = new Email();
			return $Email->preSendMail(($this->inRecuperarAcesso == 1?5:3),
					$usuario['idusuario'],
					array($this->emailLoginRecover));
		}
	}
}
