<?php

/**
 * This is the model base class for the table Constants::SCHEMA_SINASE.".condicao".
 *
 * Columns in table Constants::SCHEMA_SINASE.".condicao" available as properties of the model:
 * @property integer $idcondicao
 * @property integer $idpesquisa
 * @property string $txcondicao
 * @property string $dtcriacao
 * @property integer $idusuariocriacao
 * @property string $cotipopesquisa
 *
 * Relations of table Constants::SCHEMA_SINASE.".condicao" available as properties of the model:
 * @property Tipopesquisa $cotipopesquisa
 * @property Usuario $idusuariocriacao
 * @property Pesquisa $idpesquisa
 */
abstract class BaseCondicao extends CActiveRecord{
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.condicao';
	}

	public function rules()
	{
		return array(
				array('idpesquisa, txcondicao, dtcriacao, idusuariocriacao', 'required'),
				array('cotipopesquisa', 'default', 'setOnEmpty' => true, 'value' => null),
				array('idpesquisa, idusuariocriacao', 'numerical', 'integerOnly'=>true),
				array('txcondicao', 'length', 'max'=>300),
				array('cotipopesquisa', 'length', 'max'=>3),


				array('idcondicao, idpesquisa, txcondicao, dtcriacao, idusuariocriacao, cotipopesquisa', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function relations()
	{
		return array(
				'cotipopesquisa' => array(self::BELONGS_TO, 'Tipopesquisa', 'cotipopesquisa'),
				'idusuariocriacao' => array(self::BELONGS_TO, 'Usuario', 'idusuariocriacao'),
				'idpesquisa' => array(self::BELONGS_TO, 'Pesquisa', 'idpesquisa'),
		);
	}

	/*
	 * Lista de atributos da model para adcionar no arquivo Translation
	* /protected/messages/pt_br/app.php
	'breadcrumbs.condicao' => 'Condicao',
	'condicao.idcondicao' => 'Idcondicao',
	'condicao.idpesquisa' => 'Idpesquisa',
	'condicao.txcondicao' => 'Txcondicao',
	'condicao.dtcriacao' => 'Dtcriacao',
	'condicao.idusuariocriacao' => 'Idusuariocriacao',
	'condicao.cotipopesquisa' => 'Cotipopesquisa',
	*/
	public function attributeLabels()
	{
		return array(
				'idcondicao' => Yii::t('app', 'condicao.idcondicao'),
				'idpesquisa' => Yii::t('app', 'condicao.idpesquisa'),
				'txcondicao' => Yii::t('app', 'condicao.txcondicao'),
				'dtcriacao' => Yii::t('app', 'condicao.dtcriacao'),
				'idusuariocriacao' => Yii::t('app', 'condicao.idusuariocriacao'),
				'cotipopesquisa' => Yii::t('app', 'condicao.cotipopesquisa'),
		);
	}

	public function search()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('idcondicao', $this->idcondicao);
		$criteria->compare('idpesquisa', $this->idpesquisa);
		$criteria->compare('txcondicao', $this->txcondicao, true);
		$criteria->compare('dtcriacao', $this->dtcriacao, true);
		$criteria->compare('idusuariocriacao', $this->idusuariocriacao);
		$criteria->compare('cotipopesquisa', $this->cotipopesquisa);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function get_label()
	{
		return '#'.$this->idcondicao;
	}

}
