<?php

/**
 * This is the model base class for the table Constants::SCHEMA_SINASE.".email".
 *
 * Columns in table Constants::SCHEMA_SINASE.".email" available as properties of the model:
 * @property integer $idemail
 * @property integer $idemailtipoenvio
 * @property string $dctitulo
 * @property string $dccorpoemail
 * @property string $dctitulonovo
 * @property boolean $inativo
 * @property boolean $inenviomanual
 *
 * Relations of table Constants::SCHEMA_SINASE.".email" available as properties of the model:
 * @property Emailtag[] $scPortalsinase.emailtags
 * @property Emailtipoenvio $idemailtipoenvio
 */
abstract class BaseEmail extends CActiveRecord{
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.email';
	}

	public function rules()
	{
		return array(
				array('dctitulo', 'unique'),
				array('dctitulo', 'identificationColumnValidator'),
				array('idemail, idemailtipoenvio, dctitulo, dccorpoemail', 'required'),
				array('dctitulonovo, inativo, inenviomanual', 'default', 'setOnEmpty' => true, 'value' => null),
				array('idemail, idemailtipoenvio', 'numerical', 'integerOnly'=>true),
				array('dctitulo, dctitulonovo', 'length', 'max'=>100),
				array('dccorpoemail', 'length', 'max'=>10485760),
				array('inativo, inenviomanual', 'safe'),

				array('idemail, idemailtipoenvio, dctitulo, dccorpoemail, dctitulonovo, inativo, inenviomanual', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function relations()
	{
		return array(
				'scPortalsinase.emailtags' => array(self::MANY_MANY, 'Emailtag', 'emailgrupotag(idemail, idemailtag)'),
				'idemailtipoenvio' => array(self::BELONGS_TO, 'Emailtipoenvio', 'idemailtipoenvio'),
		);
	}

	/*
	 * Lista de atributos da model para adcionar no arquivo Translation
	* /protected/messages/pt_br/app.php
	'breadcrumbs.email' => 'Email',
	'email.idemail' => 'Idemail',
	'email.idemailtipoenvio' => 'Idemailtipoenvio',
	'email.dctitulo' => 'Dctitulo',
	'email.dccorpoemail' => 'Dccorpoemail',
	'email.dctitulonovo' => 'Dctitulonovo',
	'email.inativo' => 'Inativo',
	'email.inenviomanual' => 'Inenviomanual',
	*/
	public function attributeLabels()
	{
		return array(
				'idemail' => Yii::t('app', 'email.idemail'),
				'idemailtipoenvio' => Yii::t('app', 'email.idemailtipoenvio'),
				'dctitulo' => Yii::t('app', 'email.dctitulo'),
				'dccorpoemail' => Yii::t('app', 'email.dccorpoemail'),
				'dctitulonovo' => Yii::t('app', 'email.dctitulonovo'),
				'inativo' => Yii::t('app', 'email.inativo'),
				'inenviomanual' => Yii::t('app', 'email.inenviomanual'),
		);
	}

	public function search()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('idemail', $this->idemail);
		$criteria->compare('idemailtipoenvio', $this->idemailtipoenvio);
		$criteria->compare('dctitulo', $this->dctitulo, true);
		$criteria->compare('dccorpoemail', $this->dccorpoemail, true);
		$criteria->compare('dctitulonovo', $this->dctitulonovo, true);
		$criteria->compare('inativo', $this->inativo);
		$criteria->compare('inenviomanual', $this->inenviomanual);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function get_label()
	{
		return '#'.$this->idemail;
	}

}
