<?php

/**
 * This is the model class for table Constants::SCHEMA_SINASE.".mensagem".
 *
 * The followings are the available columns in table Constants::SCHEMA_SINASE.'.mensagem':
 * @property integer $idmensagem
 * @property integer $idprojeto
 * @property integer $idcursomoodle
 * @property integer $idturmamoodle
 * @property integer $idusuariodestinatario
 * @property integer $idusuariocriacao
 * @property string $dcassunto
 * @property string $dcmensagem
 * @property string $dtcriacao
 * @property string $dtexpiracao
 * @property string $dtpublicacao
 *
 * The followings are the available model relations:
 * @property Usuario[] $scPortalsinase.usuarios
 * @property Usuario $idusuariocriacao0
 * @property Usuario $idusuariodestinatario0
 * @property Projeto $idprojeto0
 */
class BaseMensagem extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return BaseMensagem the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.mensagem';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
				array('idusuariocriacao, dcassunto, dcmensagem, dtcriacao', 'required'),
				array('idprojeto, idcursomoodle, idturmamoodle, idusuariodestinatario, idusuariocriacao', 'numerical', 'integerOnly'=>true),
				array('dcassunto', 'length', 'max'=>150),
				array('dtexpiracao, dtpublicacao', 'safe'),
				// The following rule is used by search().
				// Please remove those attributes that should not be searched.
				array('idmensagem, idprojeto, idcursomoodle, idturmamoodle, idusuariodestinatario, idusuariocriacao, dcassunto, dcmensagem, dtcriacao, dtexpiracao, dtpublicacao', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
				'scPortalsinase.usuarios' => array(self::MANY_MANY, 'Usuario', 'usuariomensagemlida(idmensagem, idusuario)'),
				'idusuariocriacao0' => array(self::BELONGS_TO, 'Usuario', 'idusuariocriacao'),
				'idusuariodestinatario0' => array(self::BELONGS_TO, 'Usuario', 'idusuariodestinatario'),
				'idprojeto0' => array(self::BELONGS_TO, 'Projeto', 'idprojeto'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
				'idmensagem' => 'Idmensagem',
				'idprojeto' => 'Idprojeto',
				'idcursomoodle' => 'Idcursomoodle',
				'idturmamoodle' => 'Idturmamoodle',
				'idusuariodestinatario' => 'Idusuariodestinatario',
				'idusuariocriacao' => 'Idusuariocriacao',
				'dcassunto' => 'Dcassunto',
				'dcmensagem' => 'Dcmensagem',
				'dtcriacao' => 'Dtcriacao',
				'dtexpiracao' => 'Dtexpiracao',
				'dtpublicacao' => 'Dtpublicacao',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('idmensagem',$this->idmensagem);
		$criteria->compare('idprojeto',$this->idprojeto);
		$criteria->compare('idcursomoodle',$this->idcursomoodle);
		$criteria->compare('idturmamoodle',$this->idturmamoodle);
		$criteria->compare('idusuariodestinatario',$this->idusuariodestinatario);
		$criteria->compare('idusuariocriacao',$this->idusuariocriacao);
		$criteria->compare('dcassunto',$this->dcassunto,true);
		$criteria->compare('dcmensagem',$this->dcmensagem,true);
		$criteria->compare('dtcriacao',$this->dtcriacao,true);
		$criteria->compare('dtexpiracao',$this->dtexpiracao,true);
		$criteria->compare('dtpublicacao',$this->dtpublicacao,true);

		return new CActiveDataProvider($this, array(
				'criteria'=>$criteria,
		));
	}
}
