<?php

/**
 * This is the model base class for the table Constants::SCHEMA_SINASE.".projetocurso".
 *
 * Columns in table Constants::SCHEMA_SINASE.".projetocurso" available as properties of the model:
 * @property integer $idprojeto
 * @property integer $idcursomoodle
 * @property integer $idquestionario
 * @property string $dtinicioinscricao
 * @property string $dtfiminscricao
 * @property string $dtiniciocurso
 * @property string $dtfimcurso
 *
 * Relations of table Constants::SCHEMA_SINASE.".projetocurso" available as properties of the model:
 * @property Projetocursoquestionario[] $projetocursoquestionarios
 * @property Projetocursoquestionario[] $projetocursoquestionarios1
 * @property Controleinscricao[] $controleinscricaos
 * @property Controleinscricao[] $controleinscricaos1
 * @property Questionario $idquestionario
 * @property Projeto $idprojeto
 */
abstract class BaseProjetoCurso extends CActiveRecord{

	public $nome_projeto;
	public $nome_curso;
	public $nome_questionario;
	public $respondido;
	public $situacao;

	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.projetocurso';
	}

	public function rules()
	{
		return array(
				array('idprojeto, idcursomoodle, idquestionario', 'required'),
				array('dtinicioinscricao, dtfiminscricao, dtiniciocurso, dtfimcurso', 'default', 'setOnEmpty' => true, 'value' => null),
				array('idprojeto, idcursomoodle, idquestionario', 'numerical', 'integerOnly'=>true),
				array('dtinicioinscricao, dtfiminscricao, dtiniciocurso, dtfimcurso', 'safe'),

				array('idprojeto, idcursomoodle, idquestionario, dtinicioinscricao, dtfiminscricao, dtiniciocurso, dtfimcurso', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function relations()
	{
		return array(
				'projetocursoquestionarios' => array(self::HAS_MANY, 'Projetocursoquestionario', 'idprojeto'),
				'projetocursoquestionarios1' => array(self::HAS_MANY, 'Projetocursoquestionario', 'idcursomoodle'),
				'controleinscricaos' => array(self::HAS_MANY, 'Controleinscricao', 'idprojeto'),
				'controleinscricaos1' => array(self::HAS_MANY, 'Controleinscricao', 'idcursomoodle'),
				'idquestionario' => array(self::BELONGS_TO, 'Questionario', 'idquestionario'),
				'idprojeto' => array(self::BELONGS_TO, 'Projeto', 'idprojeto'),
		);
	}

	/*
	 * Lista de atributos da model para adcionar no arquivo Translation
	*
	*/
	public function attributeLabels()
	{
		return array(
				'idprojeto' => Yii::t('app', 'projetocurso.idprojeto'),
				'idcursomoodle' => Yii::t('app', 'projetocurso.idcursomoodle'),
				'idquestionario' => Yii::t('app', 'projetocurso.idquestionario'),
				'dtinicioinscricao' => Yii::t('app', 'projetocurso.dtinicioinscricao'),
				'dtfiminscricao' => Yii::t('app', 'projetocurso.dtfiminscricao'),
				'dtiniciocurso' => Yii::t('app', 'projetocurso.dtiniciocurso'),
				'dtfimcurso' => Yii::t('app', 'projetocurso.dtfimcurso'),
		);
	}

	public function search()
	{
		parent::beforeFind();

		$criteria=new CDbCriteria;
		$criteria->compare('idprojeto', $this->idprojeto);
		$criteria->compare('idcursomoodle', $this->idcursomoodle);
		$criteria->compare('idquestionario', $this->idquestionario);
		$criteria->compare('dtinicioinscricao', $this->dtinicioinscricao, true);
		$criteria->compare('dtfiminscricao', $this->dtfiminscricao, true);
		$criteria->compare('dtiniciocurso', $this->dtiniciocurso, true);
		$criteria->compare('dtfimcurso', $this->dtfimcurso, true);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function search2($questionario = FALSE)
	{
// 		$usuarioMoodle = new UsuarioMoodle();
// 		$dadosUsuarioMoodle = $usuarioMoodle->findByAttributes(array('idusuario'=>Yii::app()->user->id));


		$criteria=new CDbCriteria;

		$criteria->alias = 'pc';
		$criteria->select = "p.dcprojeto AS nome_projeto, c.fullname AS nome_curso, pc.idprojeto, pc.idcursomoodle, pc.dtiniciocurso, pc.dtfimcurso, (CASE ci.insituacaoalunocurso WHEN 'C' THEN 'Cursando' WHEN 'A' THEN 'Aprovado' ELSE 'Liberado o Certificado' END ) AS situacao, pc.idquestionario";

		$criteria->compare('idprojeto', $this->idprojeto);
		$criteria->compare('idcursomoodle', $this->idcursomoodle);
		$criteria->compare('idquestionario', $this->idquestionario);
		if( $this->dtiniciocurso != "" && !is_null($this->dtiniciocurso) ) {
			$dtinicio = implode("-", array_reverse( explode( "/", $this->dtiniciocurso ) ));
			$criteria->addCondition(" to_date(to_char(pc.dtiniciocurso, 'YYYY-MM-DD'), 'YYYY-MM-DD') <= '". $dtinicio ."'");
		}

		if( $this->dtfimcurso != "" && !is_null($this->dtfimcurso) ) {
			$dtfim = implode("-", array_reverse( explode( "/", $this->dtfimcurso ) ));
			$criteria->addCondition("to_date(to_char(pc.dtfimcurso, 'YYYY-MM-DD'), 'YYYY-MM-DD') >= '". $dtfim ."'");
		}
		$criteria->join = 'INNER JOIN '.Constants::SCHEMA_SINASE.'.projeto p ON pc.idprojeto=p.idprojeto ';
		$criteria->join .= 'INNER JOIN '.Constants::SCHEMA_SINASE.'.vw_curso c ON pc.idcursomoodle=c.id ';
		if($questionario === FALSE){
			$criteria->join .= 'INNER JOIN '.Constants::SCHEMA_SINASE.'.controleinscricao ci ON pc.idprojeto = ci.idprojeto AND ci.idcursomoodle = pc.idcursomoodle AND pc.idquestionario = ci.idquestionario AND ci.idusuario = '.Yii::app()->user->id;
		} else {
			$criteria->join .= 'INNER JOIN '.Constants::SCHEMA_SINASE.'.controleinscricao ci ON pc.idprojeto = ci.idprojeto AND ci.idcursomoodle = pc.idcursomoodle AND ci.idusuario = '.Yii::app()->user->id;
		}

		$criteria->group = 'p.dcprojeto, c.fullname, pc.idprojeto, pc.idcursomoodle, pc.dtiniciocurso, pc.dtfimcurso, ci.insituacaoalunocurso, pc.idquestionario';

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function search3()
	{
		$criteria=new CDbCriteria;

		$criteria->alias = 'pc';
		$criteria->select = 'q.dcformulario as nome_questionario, dtiniciocurso, dtfimcurso, COUNT( DISTINCT( idusuario ) ) as respondido, pc.idquestionario';

		$criteria->compare('pc.idprojeto', $this->idprojeto);
		$criteria->compare('pc.idcursomoodle', $this->idcursomoodle);
		$criteria->compare('pc.idquestionario', $this->idquestionario);
		$criteria->join = 'INNER JOIN '.Constants::SCHEMA_SINASE.'.questionario q ON pc.idquestionario=q.idquestionario ';
		$criteria->join .= 'LEFT JOIN '.Constants::SCHEMA_SINASE.'.usuariocursopesquisa ucp ON pc.idprojeto = ucp.idprojeto AND pc.idcursomoodle = ucp.idcursomoodle AND pc.idquestionario = ucp.idquestionario';
		$criteria->group = 'q.dcformulario, dtiniciocurso, dtfimcurso, pc.idquestionario';

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function get_label()
	{
		return '#'.$this->idprojeto;return '#'.$this->idcursomoodle;
	}

}
