<?php

/**
 * This is the model base class for the table Constants::SCHEMA_SINASE.".questao".
 *
 * Columns in table Constants::SCHEMA_SINASE.".questao" available as properties of the model:
 * @property integer $idquestao
 * @property integer $idquestionario
 * @property integer $idgrupoquestao
 * @property string $cotipoquestao
 * @property string $dcquestao
 * @property string $dcorientacao
 * @property boolean $inpermitetotalizar
 * @property boolean $inobrigatorio
 * @property integer $nuordem
 *
 * Relations of table Constants::SCHEMA_SINASE.".questao" available as properties of the model:
 * @property Resposta[] $respostas
 * @property Questionario $idquestionario
 * @property Grupoquestao $idgrupoquestao
 * @property Tipoquestao $cotipoquestao
 */
abstract class BaseQuestao extends CActiveRecord{
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.questao';
	}

	public function rules()
	{
		return array(
				array('idquestionario, idgrupoquestao, cotipoquestao, dcquestao, inobrigatorio, nuordem', 'required'),
				array('dcorientacao, inpermitetotalizar', 'default', 'setOnEmpty' => true, 'value' => null),
				array('idquestionario, idgrupoquestao, nuordem', 'numerical', 'integerOnly'=>true),
				array('cotipoquestao', 'length', 'max'=>10),
				array('dcquestao', 'length', 'max'=>80),
				array('dcorientacao, inpermitetotalizar', 'safe'),

				array('idquestao, idquestionario, idgrupoquestao, cotipoquestao, dcquestao, dcorientacao, inpermitetotalizar, inobrigatorio, nuordem', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function relations()
	{
		return array(
				'respostas' => array(self::HAS_MANY, 'Resposta', 'idquestao'),
				'idquestionario' => array(self::BELONGS_TO, 'Questionario', 'idquestionario'),
				'idgrupoquestao' => array(self::BELONGS_TO, 'Grupoquestao', 'idgrupoquestao'),
				'cotipoquestao' => array(self::BELONGS_TO, 'Tipoquestao', 'cotipoquestao'),
		);
	}

	public function attributeLabels()
	{
		return array(
				'idquestao' => Yii::t('app', 'questao.idquestao'),
				'idquestionario' => Yii::t('app', 'questao.idquestionario'),
				'idgrupoquestao' => Yii::t('app', 'questao.idgrupoquestao'),
				'cotipoquestao' => Yii::t('app', 'questao.cotipoquestao'),
				'dcquestao' => Yii::t('app', 'questao.dcquestao'),
				'dcorientacao' => Yii::t('app', 'questao.dcorientacao'),
				'inpermitetotalizar' => Yii::t('app', 'questao.inpermitetotalizar'),
				'inobrigatorio' => Yii::t('app', 'questao.inobrigatorio'),
				'nuordem' => Yii::t('app', 'questao.nuordem'),
		);
	}

	public function search()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('idquestao', $this->idquestao);
		$criteria->compare('idquestionario', $this->idquestionario);
		$criteria->compare('idgrupoquestao', $this->idgrupoquestao);
		$criteria->compare('cotipoquestao', $this->cotipoquestao);
		$criteria->compare('dcquestao', $this->dcquestao, true);
		$criteria->compare('dcorientacao', $this->dcorientacao, true);
		$criteria->compare('inpermitetotalizar', $this->inpermitetotalizar);
		$criteria->compare('inobrigatorio', $this->inobrigatorio);
		$criteria->compare('nuordem', $this->nuordem);
		$criteria->order = 'nuordem';

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

	public function search2()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('idgrupoquestao', $this->idgrupoquestao);
		$criteria->compare('cotipoquestao', $this->cotipoquestao);
		$criteria->compare('dcquestao', $this->dcquestao, true);
		$criteria->compare('dcorientacao', $this->dcorientacao, true);
		$criteria->compare('inpermitetotalizar', $this->inpermitetotalizar);
		$criteria->compare('inobrigatorio', $this->inobrigatorio);
		$criteria->compare('nuordem', $this->nuordem);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}
}
