<?php

/**
 * This is the model base class for the table Constants::SCHEMA_SINASE.".vw_cursoturma".
 *
 * Columns in table Constants::SCHEMA_SINASE.".vw_cursoturma" available as properties of the model:
 * @property string $courseid
 * @property string $fullname
 * @property string $shortname
 * @property string $id
 * @property string $idnumber
 * @property string $name
 * @property string $description
 * @property string $enrolmentkey
 * @property string $format
 * @property integer $qtselecionados
 * @property float $indqualitativo
 *
 * There are no model relations.
 */
abstract class BaseVwCursoTurma extends CActiveRecord{
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return Constants::SCHEMA_SINASE.'.vw_cursoturma';
	}

	public function rules()
	{
		return array(
				array('courseid, fullname, shortname, id, idnumber, name, description, enrolmentkey, format, qtselecionados, indqualitativo', 'default', 'setOnEmpty' => true, 'value' => null),
                array('qtselecionados', 'numerical', 'integerOnly'=>true),
				array('fullname, name', 'length', 'max'=>254, 'min'=>1),
				array('shortname', 'length', 'max'=>255, 'min'=>1),
				array('description', 'length', 'max'=>1000, 'min'=>11),
				array('idnumber', 'length', 'max'=>100),
				array('enrolmentkey', 'length', 'max'=>50),
				array('courseid, id, description, format, qtselecionados, indqualitativo', 'safe'),
				array('courseid, fullname, shortname, id, idnumber, name, description, enrolmentkey, format, qtselecionados, indqualitativo', 'safe', 'on'=>'search'),
		);
	}

	// 'ext' is in Yii 1.0.8 version. For early versions, use 'application.extensions' instead.
	// @link http://www.yiiframework.com/extension/i18n-datetime-behavior
	public function behaviors()
	{
		return array('Format18NBehavior' => array('class' => 'ext.formatBehavion-i18n.Format18NBehavior'));
	}

	public function relations()
	{
		return array(
		);
	}

	/*
	 * Lista de atributos da model para adcionar no arquivo Translation
	*
    */
	public function attributeLabels()
	{
		return array(
				'courseid' 		=> Yii::t('app', 'cursoTurma.courseid'),
				'fullname' 		=> Yii::t('app', 'cursoTurma.fullname'),
				'shortname' 	=> Yii::t('app', 'cursoTurma.shortname'),
				'id' 			=> Yii::t('app', 'cursoTurma.id'),
				'idnumber' 		=> Yii::t('app', 'cursoTurma.idnumber'),
				'name' 			=> Yii::t('app', 'cursoTurma.name'),
				'description'	=> Yii::t('app', 'cursoTurma.description'),
				'enrolmentkey'	=> Yii::t('app', 'cursoTurma.enrolmentkey'),
				'format' 		=> Yii::t('app', 'cursoTurma.format'),
                'qtselecionados'=> Yii::t('app', 'cursoTurma.qtselecionados'),
                'indqualitativo'=> Yii::t('app', 'cursoTurma.indqualitativo'),
		);
	}

	public function search()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('courseid', $this->courseid);
		$criteria->compare('fullname', $this->fullname, true);
		$criteria->compare('shortname', $this->shortname, true);
		$criteria->compare('id', $this->id);
		$criteria->compare('idnumber', $this->idnumber);
		$criteria->compare('name', $this->name, true);
		$criteria->compare('description', $this->description, true);
		$criteria->compare('enrolmentkey', $this->enrolmentkey, true);
		$criteria->compare('format', $this->format, true);
		$criteria->compare('qtselecionados', $this->qtselecionados, true);
        $criteria->compare('indqualitativo', $this->indqualitativo, true);

		return new CActiveDataProvider(get_class($this), array(
				'criteria'=>$criteria,
		));
	}

    public function afterFind() {
        $this->indqualitativo = number_format($this->indqualitativo,3,',','.');
        return parent::afterFind();
    }

}
